<?php
add_action( 'elementor/element/section/section_structure/after_section_end', 'bexpres_add_custom_section_controls' );
add_action( 'elementor/element/column/layout/after_section_end', 'bexpres_add_custom_columns_controls' );
add_action( 'elementor/element/section/section_structure/after_section_end', 'bexpres_add_custom_section_effect_image' );
add_action( 'elementor/element/section/section_structure/after_section_end', 'bexpres_add_custom_section_divider' ); 

function bexpres_add_custom_section_controls( \Elementor\Element_Base $element) {

	$element->start_controls_section(
		'section_pxl',
		[
			'label' => esc_html__( 'bexpres Settings', 'bexpres' ),
			'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
		]
	);

	$element->add_control(
		'row_scroll_fixed',
		[
			'label'   => esc_html__( 'Column Fixed', 'bexpres' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => array(
				'none'        => esc_html__( 'No', 'bexpres' ),
				'fixed'   => esc_html__( 'Yes', 'bexpres' ),
			),
			'prefix_class' => 'pxl-row-scroll-',
			'default'      => 'none',      
		]
	);

	$element->add_responsive_control(
		'pxl_section_margin',
		[
			'label' => esc_html__( 'Section Container Margin', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'vw', 'vh' ],
			'selectors' => [
				'{{WRAPPER}} > .elementor-container' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
			],
		]
	);

	$element->add_control(
		'pxl_column_overflow_gradient_top',
		[
			'label' => esc_html__('Overflow Gradient Top', 'bexpres'),
			'type' => \Elementor\Controls_Manager::SWITCHER,
			'label_on' => esc_html__( 'Yes', 'bexpres' ),
			'label_off' => esc_html__( 'No', 'bexpres' ),
			'return_value' => 'yes',
			'default' => 'no',
			'separator' => 'after',
			'prefix_class' => 'pxl-column-overflow-gradient-top-'
		]
	);

	$element->add_control(
		'pxl_column_overflow_gradient_bottom',
		[
			'label' => esc_html__('Overflow Gradient Bottom', 'bexpres'),
			'type' => \Elementor\Controls_Manager::SWITCHER,
			'label_on' => esc_html__( 'Yes', 'bexpres' ),
			'label_off' => esc_html__( 'No', 'bexpres' ),
			'return_value' => 'yes',
			'default' => 'no',
			'separator' => 'after',
			'prefix_class' => 'pxl-column-overflow-gradient-bottom-'
		]
	);

	$element->add_responsive_control(
		'pxl_section_border',
		[
			'label'   => esc_html__( 'Border Type', 'bexpres' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => array(
				'' 		 => esc_html__( 'None', 'bexpres' ),
				'solid'  => esc_html__( 'Solid', 'bexpres' ),
				'double' => esc_html__( 'Double', 'bexpres' ),
				'dotted' => esc_html__( 'Dotted', 'bexpres' ),
				'dashed' => esc_html__( 'Dashed', 'bexpres' ),
				'groove' => esc_html__( 'Groove', 'bexpres' ),
			),
			'default'    => '',
			'selectors' => [
				'{{WRAPPER}}' => 'border-style: {{VALUE}};',
			],
			'separator'    => 'before',
		]
	);

	$element->add_responsive_control(
		'pxl_section_border_width',
		[
			'label'   => esc_html__( 'Border Width', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'vw', 'vh' ],
			'range' => [
				'%' => [
					'min' => 0,
					'max' => 100,
				],
				'px' => [
					'min' => 0,
					'max' => 3000,
				],
				'vw' => [
					'min' => 0,
					'max' => 3000,
				],
				'vh' => [
					'min' => 0,
					'max' => 3000,
				],
			],
			'selectors' => [
				'{{WRAPPER}}' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'pxl_section_border!' => '',
			],
		]
	);

	$element->add_responsive_control(
		'pxl_section_border_light',
		[
			'label'   	=> esc_html__( 'Border Color - Light', 'bexpres' ),
			'type' 	  	=> \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}}' => 'border-color: {{VALUE}};',
			],
			'condition' => [
				'pxl_section_border!' => '',
			],
		]
	);

	$element->add_responsive_control(
		'pxl_section_border_dark',
		[
			'label'   	=> esc_html__( 'Border Color - Dark', 'bexpres' ),
			'type' 	  	=> \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'.dark-mode {{WRAPPER}}' => 'border-color: {{VALUE}};',
			],
			'condition' => [
				'pxl_section_border!' => '',
			],
		]
	);

	$element->add_control(
		'pxl_section_bg',
		[
			'label'   => esc_html__( 'Background Type', 'bexpres' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => array(
				'none'     => esc_html__( 'No', 'bexpres' ),
				'normal'   => esc_html__( 'Normal', 'bexpres' ),
				'overlay'  => esc_html__( 'Overlay', 'bexpres' ),
				'scroll'   => esc_html__( 'Scroll', 'bexpres' ),
				'parallax' => esc_html__( 'Parallax', 'bexpres' ),
			),
			'prefix_class' => 'pxl-section-bg-',
			'default'      => 'none',
			'separator'    => 'before',
		]
	);

	$element->add_control(
		'pxl_section_bg_light',
		[
			'label'   	=> esc_html__( 'Background - Light', 'bexpres' ),
			'type' 	  	=> \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}}' => 'background-color: {{VALUE}};',
			],
			'condition' => [
				'pxl_section_bg' => ['normal'],
			],
		]
	);

	$element->add_control(
		'pxl_section_bg_dark',
		[
			'label'   	=> esc_html__( 'Background - Dark', 'bexpres' ),
			'type' 	  	=> \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'.dark-mode {{WRAPPER}}' => 'background-color: {{VALUE}};',
			],
			'condition' => [
				'pxl_section_bg' => ['normal'],
			],
		]
	);

	$element->add_control(
		'pxl_section_overlay_light',
		[
			'label'   	=> esc_html__( 'Background Overlay - Light', 'bexpres' ),
			'type' 	  	=> \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}}:before' => 'background-color: {{VALUE}};',
			],
			'condition' => [
				'pxl_section_bg' => ['overlay'],
			],
		]
	);

	$element->add_control(
		'pxl_section_overlay_dark',
		[
			'label'   	=> esc_html__( 'Background Overlay - Dark', 'bexpres' ),
			'type' 	  	=> \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'.dark-mode {{WRAPPER}}:before' => 'background-color: {{VALUE}};',
			],
			'condition' => [
				'pxl_section_bg' => ['overlay'],
			],
		]
	);

	$element->add_control(
		'pxl_scroll_bg_img',
		[
			'label' => esc_html__( 'Scroll Background Image - Light', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'selectors' => [
				'{{WRAPPER}} .pxl-elementor-bg-scroll .scroll-element' => 'background-image: url( {{URL}} );',
			],
			'condition' => [
				'pxl_section_bg' => ['scroll'],
			],
		]
	);

	$element->add_control(
		'pxl_scroll_bg_img_dark',
		[
			'label'   	=> esc_html__( 'Scroll Background Image - Dark', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'selectors' => [
				'.dark-mode {{WRAPPER}} .pxl-elementor-bg-scroll .scroll-element' => 'background-image: url( {{URL}} );',
			],
			'condition' => [
				'pxl_section_bg' => ['scroll'],
			],
		]
	);

	$element->add_control(
		'pxl_parallax_bg_img',
		[
			'label' => esc_html__( 'Parallax Background Image - Light', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'selectors' => [
				'{{WRAPPER}} .pxl-elementor-bg-parallax .parallax-element' => 'background-image: url( {{URL}} );',
			],
			'condition' => [
				'pxl_section_bg' => ['parallax'],
			],
		]
	);

	$element->add_control(
		'pxl_parallax_bg_img_dark',
		[
			'label' => esc_html__( 'Parallax Background Image - Dark', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'selectors' => [
				'.dark-mode {{WRAPPER}} .pxl-elementor-bg-parallax .parallax-element' => 'background-image: url( {{URL}} );',
			],
			'condition' => [
				'pxl_section_bg' => ['parallax'],
			],
		]
	);

	$element->add_control(
		'pxl_parallax_overlay_light',
		[
			'label'   	=> esc_html__( 'Parallax Background Overlay', 'bexpres' ),
			'type' 	  	=> \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .pxl-elementor-bg-parallax:before' => 'background-color: {{VALUE}};',
			],
			'condition' => [
				'pxl_section_bg' => ['parallax'],
			],
		]
	);

	$element->end_controls_section();
};

function bexpres_add_custom_section_effect_image( \Elementor\Element_Base $element) {

	$element->start_controls_section(
		'section_effect_image',
		[
			'label' => esc_html__( 'bexpres Effect Images', 'bexpres' ),
			'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
		]
	);

	$repeater_img = new \Elementor\Repeater();

	$repeater_img->add_control(
		'item_image', 
		[
			'label' => esc_html__('Image', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
		]
	);
	$repeater_img->add_control(
		'item_image_dark', 
		[
			'label' => esc_html__('Image Dark', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
		]
	);

	$repeater_img->add_control(
		'image_position', 
		[
			'label' => esc_html__('Image Position', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'p-top-left' => 'Top Left',
				'p-top-right' => 'Top Right',
				'p-bottom-left' => 'Bottom Left',
				'p-bottom-right' => 'Bottom Right',
			],
			'default' => 'p-top-left',
		]
	);

	$repeater_img->add_control(
		'image_position_top', 
		[
			'label' => esc_html__('Top Position', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'control_type' => 'responsive',
			'default' => [
				'size' => 0,
				'unit' => '%',
			],
			'range' => [
				'%' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .pxl-section-effect-images {{CURRENT_ITEM}}' => 'top: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'image_position' => ['p-top-left', 'p-top-right'],
			],
		]
	);

	$repeater_img->add_control(
		'image_position_left', 
		[
			'label' => esc_html__('Left Position', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'control_type' => 'responsive',
			'default' => [
				'size' => 0,
				'unit' => '%',
			],
			'range' => [
				'%' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .pxl-section-effect-images {{CURRENT_ITEM}}' => 'left: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'image_position' => ['p-top-left', 'p-bottom-left'],
			],
		]
	);

	$repeater_img->add_control(
		'image_position_bottom', 
		[
			'label' => esc_html__('Bottom Position', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'control_type' => 'responsive',
			'default' => [
				'size' => 0,
				'unit' => '%',
			],
			'range' => [
				'%' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .pxl-section-effect-images {{CURRENT_ITEM}}' => 'bottom: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'image_position' => ['p-bottom-left', 'p-bottom-right'],
			],
		]
	);

	$repeater_img->add_control(
		'image_position_right', 
		[
			'label' => esc_html__('Right Position', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'control_type' => 'responsive',
			'default' => [
				'size' => 0,
				'unit' => '%',
			],
			'range' => [
				'%' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .pxl-section-effect-images {{CURRENT_ITEM}}' => 'right: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'image_position' => ['p-top-right', 'p-bottom-right'],
			],
		]
	);

	$repeater_img->add_control(
		'effect_image', 
		[
			'label' => esc_html__('Image Effect', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'' => 'None',
				'pxl-image-spin' => 'Spin',
				'pxl-image-bounce' => 'Bounce',
				'slide-up-down' => 'Slide Up Down',
				'slide-top-to-bottom' => 'Slide Top To Bottom ',
				'pxl-image-effect2' => 'Slide Bottom To Top ',
				'slide-right-to-left' => 'Slide Right To Left ',
				'slide-left-to-right' => 'Slide Left To Right ',
				'pxl-parallax-scroll' => 'Parallax Scroll',
				'pxl-parallax-hover' => 'Parallax Hover',
			],
			'default' => '',
		]
	);

	$repeater_img->add_control(
		'parallax_scroll_type', 
		[
			'label' => esc_html__('Parallax Scroll Type', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'y' => 'Effect Y',
				'x' => 'Effect X',
				'z' => 'Effect Z',
			],
			'default' => 'y',
			'condition' => [
				'effect_image' => 'pxl-parallax-scroll',
			],
		]
	);

	$repeater_img->add_control(
		'parallax_scroll_value', 
		[
			'label' => esc_html__('Parallax Scroll Value', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::TEXT,
			'default' => '80',
			'description' => esc_html__('Enter number.', 'bexpres' ),
			'condition' => [
				'effect_image' => 'pxl-parallax-scroll',
			],
		]
	);

	$repeater_img->add_control(
		'parallax_hover_value', 
		[
			'label' => esc_html__('Parallax Hover Value', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::TEXT,
			'default' => '40',
			'description' => esc_html__('Enter number.', 'bexpres' ),
			'condition' => [
				'effect_image' => 'pxl-parallax-hover',
			],
		]
	);

	$repeater_img->add_control(
		'image_display', 
		[
			'label' => esc_html__('Hide on Screen <= 1400px', 'bexpres'),
			'type' => \Elementor\Controls_Manager::SWITCHER,
			'default' => 'false',
		]
	);

	$repeater_img->add_control(
		'image_display_md', 
		[
			'label' => esc_html__('Hide on Screen <= 1200px', 'bexpres'),
			'type' => \Elementor\Controls_Manager::SWITCHER,
			'default' => 'false',
		]
	);

	$repeater_img->add_control(
		'image_display_sm', 
		[
			'label' => esc_html__('Hide on Screen <= 767px', 'bexpres'),
			'type' => \Elementor\Controls_Manager::SWITCHER,
			'default' => 'false',
		]
	);

	$element->add_control(
		'row_effect_images',
		[
			'label'   => esc_html__( 'Images', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::REPEATER,
			'fields' => $repeater_img->get_controls(),
			'default' => [],
		]
	);

	$element->end_controls_section();
};

function bexpres_add_custom_section_divider( \Elementor\Element_Base $element) {

	$element->start_controls_section(
		'section_divider',
		[
			'label' => esc_html__( 'bexpres Divider', 'bexpres' ),
			'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
		]
	);

	$element->add_control(
		'row_divider',
		[
			'label'   => esc_html__( 'Divider', 'bexpres' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => array(
				''        => esc_html__( 'None', 'bexpres' ),
				'vertical1'   => esc_html__( 'Divider Vertical', 'bexpres' ),
				'divider-line'   => esc_html__( 'Divider Line Right/Left', 'bexpres' ),
				'divider-border'   => esc_html__( 'Divider Broder Top/Bottom', 'bexpres' ),
			),
			'prefix_class' => 'pxl-row-divider-active pxl-row-divider-',
			'default'      => '',
		]
	);

	$element->add_control(
		'divider_color_top',
		[
			'label' => esc_html__('Divider Color Top', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .pxl-divider-border .pxl-divider-border-top' => 'background-color: {{VALUE}} !important;',
				'{{WRAPPER}} .pxl-divider-border .pxl-divider-border-bottom .loader-line-mask .loader-line' => 'background-image: linear-gradient(to bottom, {{VALUE}}, rgba(255, 255, 255, 0));',
			],
		]
	);	

	$element->add_control(
		'divider_color_borde',
		[
			'label' => esc_html__('Divider Color Border', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .pxl-divider-border .pxl-divider-border-bottom' => 'border-color: {{VALUE}} !important;',
			],
		]
	);	

	$element->add_control(
		'divider_color_bottom',
		[
			'label' => esc_html__('Divider Color Bottom', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .pxl-divider-border .pxl-divider-border-bottom .loader-line-mask .loader-line:before' => 'background-color: {{VALUE}} !important;',
			],
		]
	);

	$element->add_responsive_control(
		'divider_height_line',
		[
			'label' => esc_html__('Divider Height Line', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'control_type' => 'responsive',
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 3000,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .pxl-divider-border .pxl-divider-border-top' => 'height: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'row_divider' => ['divider-border'],
			],     
		]
	);
	$element->add_responsive_control(
		'divider_top_line',
		[
			'label' => esc_html__('Divider Top line', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'control_type' => 'responsive',
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 3000,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .pxl-divider-border .pxl-divider-border-top' => 'top: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'row_divider' => ['divider-border'],
			],     
		]
	);
	$element->add_responsive_control(
		'divider_height_elip',
		[
			'label' => esc_html__('Divider Height Elip', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'control_type' => 'responsive',
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 3000,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .pxl-divider-border .pxl-divider-border-bottom' => 'height: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'row_divider' => ['divider-border'],
			],     
		]
	);
	$element->add_responsive_control(
		'divider_bottom_elip',
		[
			'label' => esc_html__('Divider Bottom Elip', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'control_type' => 'responsive',
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 3000,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .pxl-divider-border .pxl-divider-border-bottom' => 'bottom: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'row_divider' => ['divider-border'],
			],     
		]
	);

	$element->end_controls_section();
};

add_filter( 'pxl_section_start_render', 'bexpres_custom_section_start_render', 10, 3 );
function bexpres_custom_section_start_render($html, $settings, $el){

	if(!empty($settings['pxl_scroll_bg_img']['url']) || !empty($settings['pxl_scroll_bg_img_dark']['url'])){
		$html .= '<div class="pxl-elementor-bg-scroll"><div class="pxl-overlay--gradient"></div><div class="scroll-element" data-parallax=\'{"y": -50}\'></div></div>';
	}
	if(!empty($settings['pxl_parallax_bg_img']['url']) || !empty($settings['pxl_parallax_bg_img_dark']['url'])){
		$html .= '<div class="pxl-elementor-bg-parallax"><div class="pxl-overlay--gradient"></div><div class="parallax-element"></div></div>';
	}

	return $html;
}

function bexpres_add_custom_columns_controls( \Elementor\Element_Base $element) {
	$element->start_controls_section(
		'columns_pxl',
		[
			'label' => esc_html__( 'bexpres Settings', 'bexpres' ),
			'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
		]
	);

	$element->add_control(
		'pxl_section_offset',
		[
			'label' => esc_html__( 'Section Offset', 'bexpres' ),
			'type'         => \Elementor\Controls_Manager::SELECT,
			'prefix_class' => 'pxl-section-offset-',
			'hide_in_inner' => true,
			'options'      => array(
				'none'    => esc_html__( 'None', 'bexpres' ),
				'left'   => esc_html__( 'Left', 'bexpres' ),
				'right'     => esc_html__( 'Right', 'bexpres' ),
			),
			'default'      => 'none',
		]
	);

	$element->add_control(
		'col_sticky',
		[
			'label'   => esc_html__( 'Column Sticky', 'bexpres' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => array(
				'none'           => esc_html__( 'No', 'bexpres' ),
				'sticky' => esc_html__( 'Yes', 'bexpres' ),
			),
			'default' => 'none',
			'prefix_class' => 'pxl-column-'
		]
	);

	$element->add_control(
		'col_sticky_offset_top',
		[
			'label' => esc_html__( 'Sticky Offset Top', 'bexpres' ),
			'type' => 'text',
			'description' => esc_html__('Enter number.', 'bexpres' ),
			'default'  => '100',
			'selectors' => [
				'{{WRAPPER}}.pxl-column-sticky' => 'top: {{VALUE}}'.'px',
			],
			'condition' => [
				'col_sticky' => 'sticky'
			]
		]
	);

	$element->add_control(
		'pxl_col_bg_light',
		[
			'label'   	=> esc_html__( 'Column Background - Light', 'bexpres' ),
			'type' 	  	=> \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}}' => 'background-color: {{VALUE}};',
			],
		]
	);

	$element->add_control(
		'pxl_col_bg_dark',
		[
			'label'   	=> esc_html__( 'Column Background - Dark', 'bexpres' ),
			'type' 	  	=> \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'.dark-mode {{WRAPPER}}' => 'background-color: {{VALUE}};',
			],
		]
	);

	$element->add_control(
		'pxl_col_border_radius',
		[
			'label'   => esc_html__( 'Border Radius', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'%' => [
					'min' => 0,
					'max' => 100,
				],
				'px' => [
					'min' => 0,
					'max' => 3000,
				],
			],
			'selectors' => [
				'{{WRAPPER}}' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);

	$element->end_controls_section();
}

add_filter( 'pxl-custom-section/before-render', 'bexpres_custom_section_before_render', 10, 3 );
function bexpres_custom_section_before_render($html ,$settings, $el) {

	if(!empty($settings['row_divider'])) {		
		if($settings['row_divider'] == 'divider-border') {
			$html .= '<div class="pxl-divider-border"><div class="pxl-divider-border-top"></div><div class="pxl-divider-border-bottom-effect" data-parallax=\'{"y": -80}\'><div class="pxl-divider-border-bottom"><div class="loader-line-mask"><div class="loader-line"></div></div></div></div></div>';
		}
		if($settings['row_divider'] == 'vertical1') {
			$html .=  '<div class="pxl-divider-vertical"><div class="pxl-section-line1"></div><div class="pxl-section-line2"></div><div class="pxl-section-line3"></div><div class="pxl-section-line4"></div></div>';
		}
		if($settings['row_divider'] == 'divider-line') {
			$html .= '<div class="pxl-divider-line"><div class="pxl-divider-border-left"></div><div class="pxl-divider-border-right"></div></div>';
		}
	}

	if($settings['pxl_column_overflow_gradient_top'] == 'yes') {
		$html .= '<div class="pxl-overlay-gradient-top"></div>';
	}
	if($settings['pxl_column_overflow_gradient_bottom'] == 'yes') {
		$html .= '<div class="pxl-overlay-gradient-bottom"></div>';
	}

	if(isset($settings['row_effect_images']) && !empty($settings['row_effect_images']) && count($settings['row_effect_images'])):
		$html .= '<div class="pxl-section-effect-images">';
	foreach ($settings['row_effect_images'] as $key => $value):
		$item_image = isset($value['item_image']) ? $value['item_image'] : '';
		$item_image_dark = isset($value['item_image_dark']) ? $value['item_image_dark'] : '';
		$effect_image = isset($value['effect_image']) ? $value['effect_image'] : '';
		$image_display = isset($value['image_display']) ? $value['image_display'] : '';
		$image_display_md = isset($value['image_display_md']) ? $value['image_display_md'] : '';
		$image_display_sm = isset($value['image_display_sm']) ? $value['image_display_sm'] : '';
		$parallax_scroll_type = isset($value['parallax_scroll_type']) ? $value['parallax_scroll_type'] : '';
		$parallax_scroll_value = isset($value['parallax_scroll_value']) ? $value['parallax_scroll_value'] : '';
		$hidde_class = '';
		if($image_display !== 'false') {
			$hidde_class = 'pxl-hide-sr-lg';
		}
		$hidde_class_md = '';
		if($image_display_md !== 'false') {
			$hidde_class_md = 'pxl-hide-sr-md';
		}
		$hidde_class_sm = '';
		if($image_display_sm !== 'false') {
			$hidde_class_sm = 'pxl-hide-sr-sm';
		}
		$effects = [];
		if($parallax_scroll_type == 'y' && !empty($parallax_scroll_value)){
			$effects['y'] = (int)$parallax_scroll_value;
		}
		if($parallax_scroll_type == 'x' && !empty($parallax_scroll_value)){
			$effects['x'] = (int)$parallax_scroll_value;
		}
		if($parallax_scroll_type == 'z' && !empty($parallax_scroll_value)){
			$effects['z'] = (int)$parallax_scroll_value;
		}
		$data_parallax = json_encode($effects);

		wp_enqueue_script( 'pxl-parallax-move-mouse');
		$parallax_hover_value = isset($value['parallax_hover_value']) ? $value['parallax_hover_value'] : '';

		$html .= '<img data-parallax-value="'.esc_attr($parallax_hover_value).'" data-parallax="'.esc_attr($data_parallax).'" class="pxl-item--image light elementor-repeater-item-'.$value['_id'].' '.$effect_image.' '.$hidde_class.' '.$hidde_class_md.' '.$hidde_class_sm.'" src="'.$item_image['url'].'" /><img data-parallax-value="'.esc_attr($parallax_hover_value).'" data-parallax="'.esc_attr($data_parallax).'" class="pxl-item--image dark elementor-repeater-item-'.$value['_id'].' '.$effect_image.' '.$hidde_class.' '.$hidde_class_md.' '.$hidde_class_sm.'" src="'.$item_image_dark['url'].'" />';
	endforeach;
	$html .= '<div class="pxl-overlay--gradient"></div></div>';
endif;

return $html;

}

add_action( 'elementor/element/column/layout/before_section_end', 'add_responsive_column_order', 10, 3 );
function add_responsive_column_order( $element, $args ) {
	$element->add_responsive_control(
		'responsive_column_order',
		[
			'label'   => esc_html__( 'Column Order', 'bexpres' ),
			'type' => \Elementor\Controls_Manager::NUMBER,
			'separator' => 'before',
			'selectors' => [
				'{{WRAPPER}}' => '-webkit-order: {{VALUE}}; -ms-flex-order: {{VALUE}}; order: {{VALUE}};',
			],
		]
	);
}