<?php
$settings = array_merge([
    'max_tilt' => 20,
    'speed_tilt' => 300,
    'perspective_tilt' => 1000,
], $settings);
$image_link_attributes = '';
if (!empty($settings['image_link']['url'])) {
    $image_link_attributes .= ' href="' . esc_attr($settings['image_link']['url']) . '"';
    
    if ($settings['image_link']['is_external']) {
        $image_link_attributes .= ' target="_blank"';
    }
    
    if ($settings['image_link']['nofollow']) {
        $image_link_attributes .= ' rel="nofollow"';
    }
}
$img_id = null;
if ($settings['source_type'] == 's_img' && !empty($settings['image']['id'])) {
    $img_id = $settings['image']['id'];
} elseif ($settings['source_type'] == 'f_img' && has_post_thumbnail()) {
    $img_id = get_post_thumbnail_id(get_the_ID());
}
$image_size = !empty($settings['img_size']) ? $settings['img_size'] : 'full';
$img = pxl_get_image_by_size([
    'attach_id' => $img_id,
    'thumb_size' => $image_size,
    'class' => 'no-lazyload'
]);
if ($settings['img_effect'] == 'pxl-image-parallax') {
    wp_enqueue_script('pxl-parallax-move-mouse');
}
$html_id = pxl_get_element_id($settings);
?>
<div 
    id="<?php echo esc_attr($html_id); ?>" 
    class="pxl-image-single 
        <?php echo $settings['hide_parallax_sm'] !== 'false' ? 'pxl-disable-parallax-sm' : ''; ?> 
        <?php echo !empty($settings['img_effect']) ? esc_attr($settings['img_effect']) : ''; ?> 
        <?php echo esc_attr($settings['pxl_animate']); ?>"
    data-wow-delay="<?php echo esc_attr($settings['pxl_animate_delay']); ?>ms"
    <?php if ($settings['img_effect'] == 'pxl-image-tilt') : ?>
        data-maxtilt="<?php echo esc_attr($settings['max_tilt']); ?>" 
        data-speedtilt="<?php echo esc_attr($settings['speed_tilt']); ?>" 
        data-perspectivetilt="<?php echo esc_attr($settings['perspective_tilt']); ?>"
    <?php endif; ?>
    <?php if ($settings['img_effect'] == 'pxl-parallax-scroll') : ?>
        data-parallax='{"<?php echo esc_attr($settings['parallax_scroll_type']); ?>":<?php echo esc_attr($settings['parallax_scroll_value_x']); ?>}'
    <?php endif; ?>
>
    <div class="pxl-item--inner">
        <?php if (!empty($settings['img_label'])) : ?>
            <div class="pxl-item--label wow">
                <?php echo esc_attr($settings['img_label']); ?>
            </div>
        <?php endif; ?>
        <?php if ($img_id) : ?>
            <?php if ($settings['image_type'] == 'bg') : ?>
                <div class="pxl-item--bg bg-image" style="background-image: url(<?php echo esc_url($img['url']); ?>);">
                    <?php if (!empty($settings['overlay_color'])) : ?>
                        <div class="pxl-overlay-color"></div>
                    <?php endif; ?>
                </div>
            <?php else : ?>
                <div class="pxl-item--image wow" data-parallax-value="<?php echo esc_attr($settings['parallax_value']); ?>">
                    <?php if (!empty($image_link_attributes)) : ?>
                        <a <?php echo $image_link_attributes; ?>>
                    <?php endif; ?>
                        <?php echo wp_kses_post($img['thumbnail']); ?>
                    <?php if (!empty($image_link_attributes)) : ?>
                        </a>
                    <?php endif; ?>
                    
                    <?php if (!empty($settings['overlay_color'])) : ?>
                        <div class="pxl-overlay-color"></div>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        <?php endif; ?>
    </div>
</div>