(function ($) {
    // Initialize Elementor hooks when the frontend is ready
    $(window).on('elementor/frontend/init', function () {
        const carousels = [
            'pxl_post_carousel',
            'pxl_slider_carousel',
            'pxl_gallery_carousel',
            'pxl_testimonial_carousel',
            'pxl_team_carousel',
            'pxl_colum_carousel'
            ];

        carousels.forEach(carousel => {
            elementorFrontend.hooks.addAction(`frontend/element_ready/${carousel}.default`, pxl_swiper_handler);
        });
    });

    function pxl_swiper_handler($scope) {
        // Loop through each swiper slider found within the scope
        $scope.find('.pxl-swiper-sliders').each(function (index, element) {
            var $this = $(this);
            var settings = $this.find(".pxl-swiper-container").data().settings;
            var numSlides = $this.find(".pxl-swiper-slide").length;

            var carousel_settings = {                       
                direction: settings['slide_direction'],
                effect: settings['slide_mode'],
                wrapperClass: 'pxl-swiper-wrapper',
                slideClass: 'pxl-swiper-slide',
                slidesPerView: settings['slides_to_show'],
                slidesPerGroup: settings['slides_to_scroll'],
                slidesPerColumn: settings['slide_percolumn'],
                spaceBetween: 0,
                observer: true,
                observeParents: true,
                navigation: {
                    nextEl: $this.find('.pxl-swiper-arrow-next')[0],
                    prevEl: $this.find('.pxl-swiper-arrow-prev')[0],
                },
                pagination: {
                    type: settings['pagination_type'],
                    el: $this.find('.pxl-swiper-dots')[0],
                    clickable: true,
                    modifierClass: 'pxl-swiper-pagination-',
                    bulletClass: 'pxl-swiper-pagination-bullet',
                    renderCustom: function (swiper, element, current, total) {
                        return current + ' of ' + total;
                    }
                },
                speed: settings['speed'],
                watchSlidesProgress: true,
                watchSlidesVisibility: true,
                breakpoints: {
                    0: {
                        slidesPerView: settings['slides_to_show_xs'],
                        slidesPerGroup: settings['slides_to_scroll'],
                    },
                    576: {
                        slidesPerView: settings['slides_to_show_sm'],
                        slidesPerGroup: settings['slides_to_scroll'],
                    },
                    768: {
                        slidesPerView: settings['slides_to_show_md'],
                        slidesPerGroup: settings['slides_to_scroll'],
                    },
                    992: {
                        slidesPerView: settings['slides_to_show_lg'],
                        slidesPerGroup: settings['slides_to_scroll'],
                    },
                    1200: {
                        slidesPerView: settings['slides_to_show'],
                        slidesPerGroup: settings['slides_to_scroll'],
                    },
                    1400: {
                        slidesPerView: settings['slides_to_show_xxl'],
                        slidesPerGroup: settings['slides_to_scroll'],
                    }
                },
                on: {
                    slideChangeTransitionStart: function (swiper) {
                        handleSlideChange(this);
                    },
                    slideChange: function (swiper) {
                     handleSlideChange(this);
                 },
                 sliderMove: function (swiper) {
                    handleSlideChange(this);
                },
            }
        };

            // Center slide configuration
        if(settings['center'] === 'true'){
            if (numSlides % 2 === 0) {
                carousel_settings['centeredSlides'] = false;
            } else {
                carousel_settings['centeredSlides'] = true;
                carousel_settings['initialSlide'] = Math.floor(numSlides / 2);
            }
        }

            // Loop configuration
        if (settings['loop'] || settings['loop'] === 'true') {
            carousel_settings['loop'] = true;
        }

            // Autoplay configuration
        if (settings['autoplay'] || settings['autoplay'] === 'true') {
            carousel_settings['autoplay'] = {
                delay: settings['delay'],
                disableOnInteraction: settings['pause_on_interaction']
            };
        } else {
            carousel_settings['autoplay'] = false;
        }

        if (settings['slide_mode'] === 'coverflow') {
            carousel_settings['centeredSlides'] = true;
            if ($this.hasClass('pxl-gallery-carousel4') && $this.hasClass('style2')) {
                carousel_settings['coverflowEffect'] = {
                    rotate: 50,
                    stretch: settings['stretch_cover'] || 0,
                    depth: 100,
                    modifier: 1,
                    slideShadows: false,
                };
                carousel_settings['grabCursor'] = true;
                carousel_settings['centeredSlides'] = true;
                carousel_settings['slidesPerView'] = 'auto';
                carousel_settings['loop'] = true;
            } else {
                carousel_settings['coverflowEffect'] = {
                    rotate: 0,
                    stretch: settings['stretch_cover'] || 0,
                    depth: 120,
                    modifier: 3,
                    slideShadows: false,
                };
            }
        }

        // parallax
        if(settings['parallax'] === 'true'){
            carousel_settings['parallax'] = true;
        }

        // effect
        if(settings['slide_mode'] === 'fade'){
            carousel_settings['fadeEffect'] = {
                crossFade: true
            };
        }
        if (settings['slide_mode'] === 'cards') {
            carousel_settings['cardsEffect'] = {
                slideShadows: false,
                rotate: 2,
                stretch: 5,
                depth: 100,
                modifier: 1,
            };
        }
        // Effect
        if(settings['slide_mode'] === 'cube'){
            carousel_settings['cubeEffect'] = {
                grabCursor: true,
                shadow: false,
                slideShadows: false,
                shadowOffset: 20,
                shadowScale: .94,
            };
        }

        if(settings['slide_mode'] === 'creative'){
            carousel_settings['creativeEffect'] = {
                prev: {
                    translate: [0, 0, -400],
                },
                next: {
                    translate: ["100%", 0, 0],
                },
            };
            carousel_settings['on'] = {
                init: function () {
                    console.log('swiper initialized');
                    var currentVideo = $("[data-swiper-slide-index=" + this.realIndex + "]").find("video");
                    if (currentVideo.length) {
                        currentVideo.trigger('play');
                    }
                },
            };
        }

        if (settings['reverse'] === 'true') {
            carousel_settings['autoplay']['reverseDirection'] = true;
        }
            // Special settings for .pxl-gallery-carousel5
        if ($this.hasClass('pxl-gallery-carousel5')) {
            carousel_settings['slidesPerView'] = 'auto';
            carousel_settings['autoplay'] = {
                delay: 0,
            };
            if (settings['reverse'] === 'true') {
                carousel_settings['autoplay']['reverseDirection'] = true;
            }
        }

            // Creative effects configuration
        configureCreativeEffects(settings, carousel_settings);

            // Initialize thumbnail swiper if present
        if ($this.find('.pxl-swiper-thumbs').length > 0) {
            initializeThumbnailSwiper($this, carousel_settings);
        }

            // Initialize Swiper
        var swiper = new Swiper($this.find(".pxl-swiper-container")[0], carousel_settings);

        swiper.on('slideChange', function () {
            if ($(window).width() > 991) {
                var swiperInstance = this;
                var $carousel = $($this);

                if ($carousel.hasClass('pxl-slider-carousel6')) {
                    var activeIndex = swiperInstance.activeIndex;

                    $carousel.find('.pxl-swiper-slide').css('width', '');

                    $carousel.find('.pxl-swiper-slide').eq(activeIndex).css('width', '67%');

                    $carousel.find('.pxl-swiper-slide').not(':eq(' + activeIndex + ')').css('width', '32%');

                    var totalWidth = 0;
                    $carousel.find('.pxl-swiper-slide').each(function (index) {
                        if (index >= activeIndex && index < activeIndex + 3) {
                            totalWidth += $(this).outerWidth(true);
                        }
                    });

                    var containerWidth = $carousel.find('.pxl-swiper-container').width();
                    var activeSlideWidth = $carousel.find('.pxl-swiper-slide.swiper-slide-active').outerWidth(true);
                    var translateX = (containerWidth - totalWidth + activeSlideWidth) / 2;
                    if (swiperInstance.previousIndex > activeIndex) {
                        translateX = containerWidth - totalWidth + $carousel.find('.pxl-swiper-slide').eq(activeIndex).outerWidth(true);
                    }
                    var offset = 0;
                    $carousel.find('.pxl-swiper-slide').each(function (index) {
                        if (index < activeIndex) {
                            offset += $(this).outerWidth(true);
                        }
                    });

                    translateX -= offset; 

                    if (activeIndex === 0) {
                        translateX = 0;
                    }

                    $carousel.find('.pxl-swiper-wrapper').css({
                        'transform': 'translate3d(' + translateX + 'px, 0, 0)',
                    });
                }
            }
        });

            // Handle autoplay pause on hover
        if(settings['autoplay'] === 'true' && settings['pause_on_hover'] === 'true'){
            $( $this.find('.pxl-swiper-container') ).on({
                mouseenter: function mouseenter() {
                    this.swiper.autoplay.stop();
                },
                mouseleave: function mouseleave() {
                    this.swiper.autoplay.start();
                }
            });
        }

            // Initialize custom Three.js effects if applicable
        if ($scope.find('.pxl-slider-carousel-effect').length > 0) {
            if (window.innerWidth > 767) {
                initializeThreeJsEffects($scope, swiper, settings);
            } 
        }

            // Setup navigation carousel
        setupNavigationCarousel();

            // Initialize Fancybox for image popups
        $scope.find("[data-fancybox='gallery']").fancybox({
            buttons : [
                'slideShow',
                'share',
                'zoom',
                'fullScreen',
                'close'
                ],
            loop: true
        });
    });
setBoxHeight();
setPadding();
if ($scope.find('.pxl-service-carousel').length > 0) {
    bexpres_svg_color();
}
}

function handleSlideChange(swiper) {
    var activeIndex = swiper.activeIndex;
    $(swiper.slides).each(function (index) {
        var wowElement = $(this).find('.wow');
        if (index === activeIndex) {
            wowElement.removeClass('pxl-invisible').addClass('animated');
        } else {
            wowElement.removeClass('animated').addClass('pxl-invisible');
        }

            // Remove previous and next classes
        $(this).removeClass('swiper-slide-prev swiper-slide-next swiper-slide-prev-prev swiper-slide-next-next');

            // Add custom classes for adjacent slides
        if (index === activeIndex - 1 || index === activeIndex + 1) {
            $(this).addClass('swiper-slide-prev swiper-slide-next');
        } else if (index === activeIndex - 2 || index === activeIndex + 2) {
            $(this).addClass('swiper-slide-prev-prev swiper-slide-next-next');
        }
    });
}

function configureCreativeEffects(settings, carousel_settings) {
        // Creative effects configurations
    if (settings['creative-effect'] === 'effect1') {
        carousel_settings['creativeEffect'] = {
            prev: {
                shadow: true,
                origin: "left center",
                translate: ["-5%", 0, -200],
                rotate: [0, 100, 0],
            },
            next: {
                origin: "right center",
                translate: ["5%", 0, -200],
                rotate: [0, -100, 0],
            },
        };
    } else if (settings['creative-effect'] === 'effect2') {
        carousel_settings['creativeEffect'] = {
            prev: {
                shadow: true,
                translate: [0, 0, -400],
            },
            next: {
                translate: ["100%", 0, 0],
            },
        };
    } else if (settings['creative-effect'] === 'effect3') {
        carousel_settings['creativeEffect'] = {
            prev: {
                opacity: 0,
            },
            next: {
                opacity: 0,
            },
        };
    }
}

function initializeThumbnailSwiper($this, carousel_settings) {
    var $thumbElement = $this.find('.pxl-swiper-thumbs');
    if ($thumbElement.length === 0) {
        console.warn('Thumbnail element not found.');
        return;
    }

    var thumb_settings = $thumbElement.data().settings || {};
    var thumb_carousel_settings = $.extend({
        effect: 'slide',
        direction: 'horizontal',
        spaceBetween: 5,
        slidesPerView: 6,
        centeredSlides: false,
        loop: true,
        watchSlidesProgress: true,
        slideToClickedSlide: true,
        breakpoints: {
            320: {
                slidesPerView: 1,
                spaceBetween: 5
            },
            480: {
                slidesPerView: 1,
                spaceBetween: 10
            },
            640: {
                slidesPerView: 2,
                spaceBetween: 10
            },
            768: {
                slidesPerView: 3,
                spaceBetween: 10
            },
            1024: {
                slidesPerView: 4,
                spaceBetween: 10
            },
            1200: {
                slidesPerView: 4,
                spaceBetween: 10
            },
            1600: {
                slidesPerView: 6,
                spaceBetween: 10
            }
        }
    }, thumb_settings);

    var slide_thumbs = new Swiper($thumbElement[0], thumb_carousel_settings);

    if (!slide_thumbs) {
        console.error('Failed to initialize thumbnail Swiper.');
        return;
    }
    carousel_settings['thumbs'] = { swiper: slide_thumbs };
}


function initializeThreeJsEffects($scope, swiper, settings) {
    var postSlider = $scope.find('.pxl-slider-carousel-effect');
    postSlider.each(function () {
        const sliderContainer = $(this);
        var vertex = `
        varying vec2 vUv;
        void main() {
            vUv = uv;
            gl_Position = projectionMatrix * modelViewMatrix * vec4( position, 1.0 );
        }
        `;

        var fragment = `
        varying vec2 vUv;
        uniform sampler2D currentImage;
        uniform sampler2D nextImage;
        uniform sampler2D disp;
        uniform float dispFactor;
        float intensity = 0.25;
        void main() {
            vec2 uv = vUv;
            vec4 disp = texture2D(disp, uv);
            vec2 distortedPosition = vec2(uv.x + dispFactor * (disp.r * intensity), uv.y);
            vec2 distortedPosition2 = vec2(uv.x - (1.0 - dispFactor) * (disp.r * intensity), uv.y);
            vec4 _currentImage = texture2D(currentImage, distortedPosition);
            vec4 _nextImage = texture2D(nextImage, distortedPosition2);
            vec4 finalTexture = mix(_currentImage, _nextImage, dispFactor);
            gl_FragColor = finalTexture;
        }
        `;

        let scene = new THREE.Scene();
        let imgs = Array.from(sliderContainer.find('.item--featured img'));
        const sliderImages = [];
        let imgWidth = sliderContainer.find('.item--featured img').width();
        let imgHeight = sliderContainer.find('.item--featured img').height();
        let renderWidth = imgWidth * window.devicePixelRatio;
        let renderHeight = imgHeight * window.devicePixelRatio;
        let renderSize = (($(window).height()) / imgWidth);
        let slide10 = $scope.find('.pxl-slider-carousel10').length;
        let slide2 = $scope.find('.pxl-slider-carousel2').length;
        let slide8 = $scope.find('.pxl-slider-carousel8').length;
        function getCanvasSize(renderWidth, renderHeight, renderSize) {
            let multiplier = 0;
            if (slide10 > 0) {
                if (window.innerHeight < 767) {
                    multiplier = 1.4;
                } else if (window.innerWidth < 1200) {
                    multiplier = 1.3;
                } else {
                    multiplier = 1.7;
                }
            } else if(slide2 > 0) {
                multiplier = window.innerWidth < 1200 ? 1 : 1.5;
            } 
            else if(slide8 > 0) {
                multiplier = window.innerWidth < 1200 ? 1 : 1.3;
            } 
            else {
                multiplier = window.innerWidth < 1200 ? 1.5 : 2;
            }
            let imgCanvasSize = (renderWidth / renderHeight) * renderSize * multiplier;
            return imgCanvasSize;
        }
        let imgCanvasSize = getCanvasSize(renderWidth, renderHeight, renderSize);
        const camera = new THREE.PerspectiveCamera(55, imgCanvasSize, 1, 100);
        camera.position.z = 1;

        let renderer = new THREE.WebGLRenderer({ antialias: true });
        renderer.setPixelRatio(window.devicePixelRatio);
        renderer.setClearColor(0x23272A, 1.0);
        renderer.setSize(renderWidth, renderHeight);
        sliderContainer.append(renderer.domElement);

        let textureLoader = new THREE.TextureLoader();
        textureLoader.crossOrigin = "anonymous";
        imgs.forEach(function (img) {
            let image = textureLoader.load($(img).attr('src'));
            image.magFilter = image.minFilter = THREE.LinearFilter;
            image.anisotropy = renderer.capabilities.getMaxAnisotropy();
            sliderImages.push(image);
        });

        let dispImgElement = sliderContainer.find('.pxl-image-webgl');
        let dispImgSrc = dispImgElement.attr('src');
        let dispImg = textureLoader.load(dispImgSrc);
        dispImg.wrapS = dispImg.wrapT = THREE.RepeatWrapping;

        let activeSlideIndex = 0;
        if (settings['loop'] === 'true') {
            activeSlideIndex = 1;
        }

        let mat = new THREE.ShaderMaterial({
            uniforms: {
                dispFactor: { type: "f", value: 0.0 },
                currentImage: { type: "t", value: sliderImages[activeSlideIndex] },
                nextImage: { type: "t", value: sliderImages[1] },
                disp: { type: "t", value: dispImg },
            },
            vertexShader: vertex,
            fragmentShader: fragment,
            transparent: true,
            opacity: 1.0
        });

        let geometry = new THREE.PlaneBufferGeometry(2.4, 1.16);
        let object = new THREE.Mesh(geometry, mat);
        object.position.set(0, 0, 0);
        scene.add(object);

        $(window).resize(function () {
            imgWidth = sliderContainer.find('.item--featured img').width();
            imgHeight = sliderContainer.find('.item--featured img').height();
            renderWidth = imgWidth * window.devicePixelRatio;
            renderHeight = imgHeight * window.devicePixelRatio;
            renderer.setSize(renderWidth, renderHeight);
            camera.aspect = (renderWidth / renderHeight);
            camera.updateProjectionMatrix();
        });

        let animate = () => {
            requestAnimationFrame(animate);
            renderer.render(scene, camera);
        };
        animate();

        let index = 0;

        const animateDisplace = () => {
            mat.uniforms.nextImage.value = sliderImages[index];
            mat.uniforms.nextImage.needsUpdate = true;

            TweenLite.to(mat.uniforms.dispFactor, 1, {
                value: 1,
                ease: 'Sine.easeInOut',
                onComplete: () => {
                    mat.uniforms.currentImage.value = sliderImages[index];
                    mat.uniforms.currentImage.needsUpdate = true;
                    mat.uniforms.dispFactor.value = 0.0;
                }
            });
        };

        swiper.on('slideChange', function () {
            index = this.activeIndex;
            animateDisplace();
        });

        swiper.on('slideChangeTransitionStart', function () {
            swiper.allowTouchMove = false;
            postSlider.addClass('pxl-pointerev-none');
        });

        swiper.on('slideChangeTransitionEnd', function () {
            setTimeout(function () {
                swiper.allowTouchMove = true;
                postSlider.removeClass('pxl-pointerev-none');
            }, 0);
        });
    });
}


function setupNavigationCarousel() {
    $('.pxl-navigation-carousel').parents('.elementor-section').addClass('pxl--hide-arrow');
    setTimeout(function () {
        $('.pxl-navigation-carousel .pxl-navigation-arrow-prev').on('click', function () {
            $(this).parents('.elementor-section').find('.pxl-swiper-arrow.pxl-swiper-arrow-prev').trigger('click');
        });
        $('.pxl-navigation-carousel .pxl-navigation-arrow-next').on('click', function () {
            $(this).parents('.elementor-section').find('.pxl-swiper-arrow.pxl-swiper-arrow-next').trigger('click');
        });
    }, 300);
}

function setPadding() {
    var paddingTop = $('.pxl-slider-carousel2').css('padding-top');        
    var paddingleft = $('.pxl-slider-carousel2').css('padding-right');        
    $('.pxl-slider-carousel2 canvas').css('top', paddingTop);
    $('.pxl-slider-carousel2 canvas').css('right', paddingleft);
}

function setBoxHeight() {
    var windowWidth = $(window).width();

    $('.swiper-vertical').each(function() {
        var totalHeight = 0;

        $(this).find('.pxl-swiper-slide.swiper-slide-visible').each(function() {
            var slideHeight = 0;

            if (windowWidth <= 1199) {
                $(this).find('.pxl-item--inner').each(function() {
                    var innerHeight_ver = parseInt($(this).outerHeight()) || 0;
                    slideHeight += innerHeight_ver;
                });
            } else {
                $(this).find('.pxl-item--inner img').each(function() {
                    var imgHeight_ver = parseInt($(this).attr('height')) || 0;
                    slideHeight += imgHeight_ver;
                });
            }

            var paddingTop = parseInt($(this).css('padding-top')) || 0;
            var paddingBottom = parseInt($(this).css('padding-bottom')) || 0;
            slideHeight += paddingTop + paddingBottom;

            totalHeight += slideHeight;
        });

        $(this).height(totalHeight + 'px');
    });
}

function bexpres_svg_color() {
    $('.pxl-service-carousel1 .item--icon img').each(function () {
        var $img = jQuery(this);
        var imgID = $img.attr('id');
        var imgClass = $img.attr('class');
        var imgURL = $img.attr('src');

        if (imgURL) {
            setTimeout(function () {
                jQuery.get(imgURL, function (data) {
                    var $svg = jQuery(data).find('svg');
                    if (imgID) {
                        $svg.attr('id', imgID);
                    }
                    if (imgClass) {
                        $svg.attr('class', imgClass + ' replaced-svg');
                    }
                    $svg.removeAttr('xmlns:a');
                    if (!$svg.attr('viewBox') && $svg.attr('height') && $svg.attr('width')) {
                        $svg.attr('viewBox', '0 0 24 24');
                    }
                    $img.replaceWith($svg);
                }, 'xml');
            }, 500); 
        }
    });
}

})(jQuery);
