<?php
// Register Video Player Widget
pxl_add_custom_widget(
    array(
        'name' => 'pxl_video_player',
        'title' => esc_html__('BR Video Player', 'bexpres' ),
        'icon' => 'eicon-play',
        'categories' => array('pxltheme-core'),
        'params' => array(
            'sections' => array(
                array(
                    'name' => 'section_content',
                    'label' => esc_html__('Content', 'bexpres' ),
                    'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array(
                        array(
                            'name' => 'title',
                            'label' => esc_html__('Title', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::TEXT,
                            'label_block' => true,
                        ),
                        array(
                            'name' => 'video_link',
                            'label' => esc_html__('Link', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::TEXT,
                            'default' => 'https://www.youtube.com/watch?v=SF4aHwxHtZ0'                            
                        ),
                        array(
                            'name' => 'image_type',
                            'label' => esc_html__('Image Type', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'options' => [
                                'none' => 'None',
                                'img' => 'Image',
                                'bg' => 'Background',
                                'video' => 'Video',
                            ],
                            'default' => 'none',
                        ),
                        array(
                            'name' => 'image',
                            'label' => esc_html__('Image', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::MEDIA,
                            'condition' => [
                                'image_type' => ['img', 'bg'],
                            ],
                        ),
                        array(
                            'name' => 'img_size',
                            'label' => esc_html__('Image Size', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::TEXT,
                            'description' => 'Enter image size (Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels (Example: 200x100 (Width x Height).',
                            'condition' => [
                                'image_type' => 'img',
                            ],
                        ),
                        array(
                            'name' => 'img_height',
                            'label' => esc_html__( 'Image Height', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'description' => esc_html__( 'Enter number.', 'bexpres' ),
                            'control_type' => 'responsive',
                            'size_units' => [ 'px', '%' ],
                            'default' => [
                                'unit' => 'px',
                            ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 3000,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'condition' => [
                                'image_type' => 'img',
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .pxl-video--holder img' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                        ),
                        array(
                            'name' => 'image_height',
                            'label' => esc_html__('Image Height', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'description' => esc_html__('Enter number.', 'bexpres' ),
                            'condition' => [
                                'image_type' => 'bg',
                            ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 3000,
                                ],
                            ],
                            'control_type' => 'responsive',
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .pxl-video--image' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                        ),
                        array(
                            'name' => 'btn_video_style',
                            'label' => esc_html__('Button Video Style', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'options' => [
                                'style1' => 'Style 1',
                                'style2' => 'Style 2',
                            ],
                            'default' => 'style1',
                        ),
                        array(
                            'name' => 'btn_video_position',
                            'label' => esc_html__('Button Video Position', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'options' => [
                                'p-center' => 'Center',
                                'p-top-left' => 'Top Left',
                                'p-top-right' => 'Top Right',
                                'p-bottom-left' => 'Bottom Left',
                                'p-bottom-right' => 'Bottom Right',
                            ],
                            'default' => 'p-center',
                            'condition' => [
                                'image_type' => ['img','bg'],
                            ],
                        ),
                        array(
                            'name' => 'top_position',
                            'label' => esc_html__('Top Position', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'control_type' => 'responsive',
                            'default' => [
                                'size' => 0,
                                'unit' => '%',
                            ],
                            'range' => [
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                                'px' => [
                                    'min' => 0,
                                    'max' => 3000,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--holder + .btn-video-wrap.p-top-left, {{WRAPPER}} .pxl-video--holder + .btn-video-wrap.p-top-right' => 'top: {{SIZE}}{{UNIT}};',
                            ],
                            'condition' => [
                                'btn_video_position' => ['p-top-left', 'p-top-right'],
                            ],
                        ),
                        array(
                            'name' => 'right_position',
                            'label' => esc_html__('Right Position', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'control_type' => 'responsive',
                            'default' => [
                                'size' => 0,
                                'unit' => '%',
                            ],
                            'range' => [
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                                'px' => [
                                    'min' => 0,
                                    'max' => 3000,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--holder + .btn-video-wrap.p-top-right, {{WRAPPER}} .pxl-video--holder + .btn-video-wrap.p-bottom-right' => 'right: {{SIZE}}{{UNIT}};',
                            ],
                            'condition' => [
                                'btn_video_position' => ['p-top-right', 'p-bottom-right'],
                            ],
                        ),
                        array(
                            'name' => 'bottom_position',
                            'label' => esc_html__('Bottom Position', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'control_type' => 'responsive',
                            'default' => [
                                'size' => 0,
                                'unit' => '%',
                            ],
                            'range' => [
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                                'px' => [
                                    'min' => 0,
                                    'max' => 3000,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--holder + .btn-video-wrap.p-bottom-left, {{WRAPPER}} .pxl-video--holder + .btn-video-wrap.p-bottom-right' => 'bottom: {{SIZE}}{{UNIT}};',
                            ],
                            'condition' => [
                                'btn_video_position' => ['p-bottom-left', 'p-bottom-right'],
                            ],
                        ),
                        array(
                            'name' => 'left_position',
                            'label' => esc_html__('Left Position', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'control_type' => 'responsive',
                            'default' => [
                                'size' => 0,
                                'unit' => '%',
                            ],
                            'range' => [
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                                'px' => [
                                    'min' => 0,
                                    'max' => 3000,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--holder + .btn-video-wrap.p-top-left, {{WRAPPER}} .pxl-video--holder + .btn-video-wrap.p-bottom-left' => 'left: {{SIZE}}{{UNIT}};',
                            ],
                            'condition' => [
                                'btn_video_position' => ['p-top-left', 'p-bottom-left'],
                            ],
                        ),
                    ),
                ),
                array(
                    'name' => 'section_style_content',
                    'label' => esc_html__('Content', 'bexpres'),
                    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                    'controls' => array(
                        array(
                            'name' => 'title_color',
                            'label' => esc_html__('Title Color', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .pxl-item--title' => 'color: {{VALUE}};',
                            ],
                        ),
                        
                        array(
                            'name' => 'title_typography',
                            'label' => esc_html__('Title Typography', 'bexpres' ),
                            'type' => \Elementor\Group_Control_Typography::get_type(),
                            'control_type' => 'group',
                            'selector' => '{{WRAPPER}} .pxl-video-player .pxl-item--title',
                        ),
                        array(
                            'name' => 'title_width',
                            'label' => esc_html__('Title Max Width', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'control_type' => 'responsive',
                            'size_units' => [ 'px', '%' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 3000,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .pxl-item--title' => 'max-width: {{SIZE}}{{UNIT}};',
                            ],
                        ),
                        array(
                            'name' => 'title_margin',
                            'label' => esc_html__('Title Margin (px)', 'bexpres' ),
                            'type' => 'dimensions',
                            'control_type' => 'responsive',
                            'size_units' => [ 'px', '%' ],
                            'default' => [
                                'unit' => 'px',
                            ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 3000,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .pxl-item--title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                            'separator' => 'after',
                        ),
                        array(
                            'name' => 'icon_color',
                            'label' => esc_html__('Icon Color', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .btn-video' => 'color: {{VALUE}};',
                            ],
                        ),
                        
                        array(
                            'name'  => 'icon_size',
                            'label' => esc_html__('Icon Size (px)', 'bexpres' ),
                            'type'  => 'slider',
                            'control_type' => 'responsive',
                            'size_units' => ['px'],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 300,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .btn-video i' => 'font-size: {{SIZE}}{{UNIT}};',
                            ],
                        ),
                        array(
                            'name' => 'icon_width',
                            'label' => esc_html__('Icon Width (px)', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'control_type' => 'responsive',
                            'size_units' => ['px'],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 3000,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .btn-video' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
                            ],
                        ),
                        array(
                            'name' => 'btn_color_border',
                            'label' => esc_html__('Button Border Color', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .btn-video' => '1px solid color: {{VALUE}};',
                            ],
                        ),
                    ),
                ),
                array(
                    'name' => 'section_style_box',
                    'label' => esc_html__('Box', 'bexpres'),
                    'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                    'controls' => array(
                        array(
                            'name' => 'bg_position',
                            'label' => esc_html__( 'Background Position', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'default' => '',
                            'responsive' => true,
                            'options' => [
                                '' => esc_html__( 'Default', 'bexpres' ),
                                'center center' => esc_html__( 'Center Center', 'bexpres' ),
                                'center left' => esc_html__( 'Center Left', 'bexpres' ),
                                'center right' => esc_html__( 'Center Right', 'bexpres' ),
                                'top center' => esc_html__( 'Top Center', 'bexpres' ),
                                'top left' => esc_html__( 'Top Left', 'bexpres' ),
                                'top right' => esc_html__( 'Top Right', 'bexpres' ),
                                'bottom center' => esc_html__( 'Bottom Center', 'bexpres' ),
                                'bottom left' => esc_html__( 'Bottom Left', 'bexpres' ),
                                'bottom right' => esc_html__( 'Bottom Right', 'bexpres' ),
                                'initial' => esc_html__( 'Custom', 'bexpres' ),
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--image' => 'background-position: {{VALUE}};',
                            ],
                            'condition' => [
                                'image_type' => 'bg',
                            ],
                        ),
                        array(
                            'name' => 'bg_position_xpos',
                            'label' => esc_html__( 'X Position', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'responsive' => true,
                            'size_units' => [ 'px', 'em', '%', 'vw' ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 0,
                            ],
                            'tablet_default' => [
                                'unit' => 'px',
                                'size' => 0,
                            ],
                            'mobile_default' => [
                                'unit' => 'px',
                                'size' => 0,
                            ],
                            'range' => [
                                'px' => [
                                    'min' => -800,
                                    'max' => 800,
                                ],
                                'em' => [
                                    'min' => -100,
                                    'max' => 100,
                                ],
                                '%' => [
                                    'min' => -100,
                                    'max' => 100,
                                ],
                                'vw' => [
                                    'min' => -100,
                                    'max' => 100,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--image' => 'background-position: {{SIZE}}{{UNIT}} {{bg_position_ypos.SIZE}}{{bg_position_ypos.UNIT}}',
                            ],
                            'condition' => [
                                'image_type' => 'bg',
                                'bg_position' => [ 'initial' ],
                            ],
                            'required' => true,
                        ),
                        array(
                            'name' => 'bg_position_ypos',
                            'label' => esc_html__( 'Y Position', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'responsive' => true,
                            'size_units' => [ 'px', 'em', '%', 'vw' ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 0,
                            ],
                            'tablet_default' => [
                                'unit' => 'px',
                                'size' => 0,
                            ],
                            'mobile_default' => [
                                'unit' => 'px',
                                'size' => 0,
                            ],
                            'range' => [
                                'px' => [
                                    'min' => -800,
                                    'max' => 800,
                                ],
                                'em' => [
                                    'min' => -100,
                                    'max' => 100,
                                ],
                                '%' => [
                                    'min' => -100,
                                    'max' => 100,
                                ],
                                'vw' => [
                                    'min' => -100,
                                    'max' => 100,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--image' => 'background-position: {{bg_position_xpos.SIZE}}{{bg_position_xpos.UNIT}} {{SIZE}}{{UNIT}}',
                            ],
                            'condition' => [
                                'image_type' => 'bg',
                                'bg_position' => [ 'initial' ],
                            ],
                            'required' => true,
                        ),
                        array(
                            'name' => 'bg_attachment',
                            'label' => esc_html__( 'Background Attachment', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'default' => '',
                            'options' => [
                                '' => esc_html__( 'Default', 'bexpres' ),
                                'scroll' => esc_html__( 'Scroll', 'bexpres' ),
                                'fixed' => esc_html__( 'Fixed', 'bexpres' ),
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--image' => 'background-attachment: {{VALUE}};',
                            ],
                            'condition' => [
                                'image_type' => 'bg',
                            ],
                        ),
                        array(
                            'name' => 'bg_attachment_alert',
                            'type' => \Elementor\Controls_Manager::RAW_HTML,
                            'content_classes' => 'elementor-control-field-description',
                            'raw' => esc_html__( 'Note: Attachment Fixed works only on desktop.', 'bexpres' ),
                            'separator' => 'none',
                            'condition' => [
                                'image_type' => 'bg',
                                'bg_attachment' => 'fixed',
                            ],
                        ),
                        array(
                            'name' => 'bg_repeat',
                            'label' => esc_html__( 'Background Repeat', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'default' => '',
                            'responsive' => true,
                            'options' => [
                                '' => esc_html__( 'Default', 'bexpres' ),
                                'no-repeat' => esc_html__( 'No-repeat', 'bexpres' ),
                                'repeat' => esc_html__( 'Repeat', 'bexpres' ),
                                'repeat-x' => esc_html__( 'Repeat-x', 'bexpres' ),
                                'repeat-y' => esc_html__( 'Repeat-y', 'bexpres' ),
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--image' => 'background-repeat: {{VALUE}};',
                            ],
                            'condition' => [
                                'image_type' => 'bg',
                            ],
                        ),
                        array(
                            'name' => 'bg_size',
                            'label' => esc_html__( 'Background Size', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'default' => '',
                            'responsive' => true,
                            'options' => [
                                '' => esc_html__( 'Default', 'bexpres' ),
                                'auto' => esc_html__( 'Auto', 'bexpres' ),
                                'cover' => esc_html__( 'Cover', 'bexpres' ),
                                'contain' => esc_html__( 'Contain', 'bexpres' ),
                                'initial' => esc_html__( 'Custom', 'bexpres' ),
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--image' => 'background-size: {{VALUE}};',
                            ],
                            'condition' => [
                                'image_type' => 'bg',
                            ],
                        ),
                        array(
                            'name' => 'bg_width',
                            'label' => esc_html__( 'Background Width', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SLIDER,
                            'responsive' => true,
                            'size_units' => [ 'px', 'em', '%', 'vw' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 1000,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                                'vw' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'size' => 100,
                                'unit' => '%',
                            ],
                            'required' => true,
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--image' => 'background-size: {{SIZE}}{{UNIT}} auto',
                            ],
                            'condition' => [
                                'image_type' => 'bg',
                                'bg_size' => [ 'initial' ],
                            ],
                        ),
                        array(
                            'name' => 'box_bgcolor',
                            'label' => esc_html__('Background Color', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .btn-video' => 'background-color: {{VALUE}};',
                            ],
                        ),
                       
                        array(
                            'name' => 'box_border_radius',
                            'label' => esc_html__('Border Radius', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%' ],
                            'control_type' => 'responsive',
                            'default' => [
                                'unit' => 'px',
                            ],
                            'range' => [
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                                'px' => [
                                    'min' => 0,
                                    'max' => 300,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .pxl-video--inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                        ),
                        array(
                            'name' => 'overlay_color',
                            'label' => esc_html__('Overlay Color', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .pxl-video--holder:before' => 'background-color: {{VALUE}};',
                            ],
                        ),
                        array(
                            'name'  => 'overlay-opacity',
                            'label' => esc_html__( 'Overlay Opacity', 'bexpres' ),
                            'type'  => 'slider',
                            'control_type' => 'responsive',
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 9,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video-player .pxl-video--holder:before' => 'opacity: 0.{{SIZE}};',
                            ],
                            'separator' => 'after',
                        ),
                        
                        array(
                            'name' => 'object_fit',
                            'label' => esc_html__( 'Size', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'options' => [
                                '' => esc_html__( 'Default', 'bexpres' ),
                                'none' => esc_html__( 'None', 'bexpres' ),
                                'cover' => esc_html__( 'Cover', 'bexpres' ),
                                'contain' => esc_html__( 'Contain', 'bexpres' ),
                                'fill' => esc_html__( 'Fill', 'bexpres' ),
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--holder img' => 'object-fit: {{VALUE}};',
                            ],
                            'condition' => [
                                'image_type' => 'img',
                            ],
                        ),
                        array(
                            'name' => 'border_type',
                            'label' => esc_html__( 'Border Type', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'options' => [
                                '' => esc_html__( 'None', 'bexpres' ),
                                'solid' => esc_html__( 'Solid', 'bexpres' ),
                                'double' => esc_html__( 'Double', 'bexpres' ),
                                'dotted' => esc_html__( 'Dotted', 'bexpres' ),
                                'dashed' => esc_html__( 'Dashed', 'bexpres' ),
                                'groove' => esc_html__( 'Groove', 'bexpres' ),
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--holder img' => 'border-style: {{VALUE}};',
                            ],
                        ),
                        array(
                            'name' => 'border_width',
                            'label' => esc_html__( 'Border Width', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::DIMENSIONS,
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--holder img ' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                            'condition' => [
                                'border_type!' => '',
                            ],
                            'responsive' => true,
                        ),
                        array(
                            'name' => 'border_color',
                            'label' => esc_html__( 'Border Color', 'bexpres' ),
                            'type' => \Elementor\Controls_Manager::COLOR,
                            'default' => '',
                            'selectors' => [
                                '{{WRAPPER}} .pxl-video--holder img' => 'border-color: {{VALUE}};',
                            ],
                            'condition' => [
                                'border_type!' => '',
                            ],
                        ),
                        
                    ),
                ),
                bexpres_widget_animation_settings()
            ),
        ),
    ),
    bexpres_get_class_widget_path()
);