<?php
/**
 * Helper functions for the theme
 *
 * @package Bravisthemes
 */


function bexpres_html($html){
    return $html;
}

/**
 * Google Fonts
*/
function bexpres_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = 'latin,latin-ext';

    if ( 'off' !== _x( 'on', 'Montserrat:ital font: on or off', 'bexpres' ) ) {
        $fonts[] = 'Montserrat:ital,wght@0,100..900;1,100..900';
    }

    if ( 'off' !== _x( 'on', 'Poppins:ital font: on or off', 'bexpres' ) ) {
        $fonts[] = 'Poppins:ital,wght@0,100..900;1,100..900';
    }
    

    if ( $fonts ) {
        $fonts_url = add_query_arg( array(
            'family' => implode( '&family=', $fonts ),
            'subset' => urlencode( $subsets ),
        ), '//fonts.googleapis.com/css2' );
    }
    return $fonts_url;
}

/*
 * Get page ID by Slug
*/
function bexpres_get_id_by_slug($slug, $post_type){
    $content = get_page_by_path($slug, OBJECT, $post_type);
    $id = $content->ID;
    return $id;
}

/**
 * Show content by slug
 **/
function bexpres_content_by_slug($slug, $post_type){
    $content = bexpres_get_content_by_slug($slug, $post_type);

    $id = bexpres_get_id_by_slug($slug, $post_type);
    echo apply_filters('the_content',  $content);
}

/**
 * Get content by slug
 **/
function bexpres_get_content_by_slug($slug, $post_type){
    $content = get_posts(
        array(
            'name'      => $slug,
            'post_type' => $post_type
        )
    );
    if(!empty($content))
        return $content[0]->post_content;
    else
        return;
}


/**
 * Custom Comment List
 */
function bexpres_comment_list( $comment, $args, $depth ) {
    $myclass = 'icon-share-alt';
    if ( 'div' === $args['style'] ) {
        $tag       = 'div';
        $add_below = 'comment';
    } else {
        $tag       = 'li';
        $add_below = 'div-comment';
    }
    ?>
    <<?php echo ''.$tag ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
        <div id="div-comment-<?php comment_ID() ?>" class="comment-body">
        <?php endif; ?>
        <div class="comment-inner">
            <?php if ($args['avatar_size'] != 0) echo get_avatar($comment, 90); ?>
            <div class="comment-content">
                <h6 class="comment-title">
                    <?php printf( '%s', get_comment_author_link() ); ?>
                </h6>
                <div class="comment-reply">
                    <?php comment_reply_link( array_merge( $args, array(
                        'reply_text' => __('<span>Reply</span>', 'bexpres'),
                        'add_below' => $add_below,
                        'depth'     => $depth,
                        'max_depth' => $args['max_depth']
                    ) ) ); ?>
                </div>
                <div class="comment-text"><?php comment_text(); ?></div>
                <div class="technicality">
                   <div class="icon-technicality">
                   <svg xmlns="http://www.w3.org/2000/svg" width="11" height="12" viewBox="0 0 11 12" fill="none">
                        <path d="M10.0289 4.55668L5.9186 0.365694C5.65237 0.0907926 5.27122 -0.0401602 4.89734 0.0108214L1.55667 0.481652C1.4238 0.500645 1.33069 0.626599 1.34912 0.76305C1.36706 0.899501 1.4912 0.993467 1.62165 0.976973L4.96232 0.506143C5.18539 0.473155 5.41524 0.553626 5.57672 0.719566L9.68698 4.91056C10.3445 5.58831 10.3479 6.69441 9.69183 7.37967L9.59969 7.47913C9.49834 7.14075 9.31843 6.82237 9.05948 6.55546L4.94874 2.36497C4.68252 2.09007 4.30039 1.95912 3.92748 2.0106L0.586809 2.48143C0.476245 2.49693 0.390897 2.58789 0.378289 2.70135L0.00731902 6.15811C-0.03293 6.53747 0.0941212 6.90934 0.356468 7.17974L4.43811 11.3412C4.8503 11.7661 5.39778 12 5.98067 12H5.98746C6.57325 11.998 7.12268 11.7606 7.5339 11.3307L9.06966 9.72732C9.49931 9.27848 9.70831 8.68719 9.69619 8.09941L10.0395 7.72804C10.8794 6.85136 10.8755 5.42887 10.0289 4.55668ZM8.72536 9.37645L7.1896 10.9799C6.86954 11.3142 6.44184 11.4992 5.98649 11.5007H5.98115C5.52775 11.5007 5.10246 11.3187 4.78047 10.9874L0.698342 6.82487C0.541225 6.66292 0.465576 6.44 0.489338 6.21259L0.839456 2.94976L3.99246 2.50542C4.2165 2.47393 4.44538 2.55291 4.60687 2.71885L8.71712 6.90984C9.37468 7.58759 9.37808 8.69419 8.72536 9.37645ZM3.39503 5.00252C3.39503 5.27842 3.17778 5.50234 2.9101 5.50234C2.64242 5.50234 2.42517 5.27842 2.42517 5.00252C2.42517 4.72662 2.64242 4.5027 2.9101 4.5027C3.17778 4.5027 3.39503 4.72662 3.39503 5.00252Z" fill="#113741"/>
                        </svg>
                   </div>
                Technology</div>
                <div class="display-mes">
                    <div class="icon-mes">
                        <svg xmlns="http://www.w3.org/2000/svg" width="12" height="12" viewBox="0 0 12 12" fill="none">
                            <path d="M6 0C2.6915 0 0 2.6915 0 6C0 9.3085 2.6915 12 6 12H12V6C12 2.6915 9.3085 0 6 0ZM11.5 11.5H6C2.9675 11.5 0.5 9.0325 0.5 6C0.5 2.9675 2.9675 0.5 6 0.5C9.0325 0.5 11.5 2.9675 11.5 6V11.5ZM6.5 6C6.5 6.276 6.276 6.5 6 6.5C5.724 6.5 5.5 6.276 5.5 6C5.5 5.724 5.724 5.5 6 5.5C6.276 5.5 6.5 5.724 6.5 6ZM9 6C9 6.276 8.776 6.5 8.5 6.5C8.224 6.5 8 6.276 8 6C8 5.724 8.224 5.5 8.5 5.5C8.776 5.5 9 5.724 9 6ZM4 6C4 6.276 3.776 6.5 3.5 6.5C3.224 6.5 3 6.276 3 6C3 5.724 3.224 5.5 3.5 5.5C3.776 5.5 4 5.724 4 6Z" fill="#113741"/>
                        </svg>
                    </div>    
                    <?php
                        $comments_number = get_comments_number(); 
                        echo '<p>'. '0' . $comments_number . ' Message:</p>';
                    ?>
                </div>    
            </div>
        </div>
        <?php if ( 'div' != $args['style'] ) : ?>
        </div>
    <?php endif;
}

/**
 * Paginate Links
 */
function bexpres_ajax_paginate_links($link){
    $parts = parse_url($link);
    if( !isset($parts['query']) ) return $link;
    parse_str($parts['query'], $query);
    if(isset($query['page']) && !empty($query['page'])){
        return '#' . $query['page'];
    }
    else{
        return '#1';
    }
}

/* Mouse Move Animation */
function bexpres_mouse_move_animation() { 
    $mouse_move_animation = bexpres()->get_theme_opt('mouse_move_animation', false); 
    if($mouse_move_animation) {
        wp_enqueue_script( 'bexpres-cursor', get_template_directory_uri() . '/assets/js/libs/cursor.js', array( 'jquery' ), '1.0.0', true ); ?>  
        <div class="pxl-cursor pxl-js-cursor">
            <div class="pxl-cursor-wrapper">
                <div class="pxl-cursor--follower pxl-js-follower"></div>
                <div class="pxl-cursor--label pxl-js-label"></div>
                <div class="pxl-cursor--drap pxl-js-drap"></div>
                <div class="pxl-cursor--icon pxl-js-icon"></div>
            </div>
        </div>
    <?php }
}


/**
 * RGB Color
 */
function bexpres_hex_rgb($color) {

    $default = '0,0,0';

    //Return default if no color provided
    if(empty($color))
        return $default;

    //Sanitize $color if "#" is provided
    if ($color[0] == '#' ) {
        $color = substr( $color, 1 );
    }

    //Check if color has 6 or 3 characters and get values
    if (strlen($color) == 6) {
        $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
    } elseif ( strlen( $color ) == 3 ) {
        $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
    } else {
        return $default;
    }

    //Convert hexadec to rgb
    $rgb =  array_map('hexdec', $hex);

    $output = implode(",",$rgb);

    //Return rgb(a) color string
    return $output;
}


/**
 * Image Size Crop
 */
if(!function_exists('bexpres_get_image_by_size')){
    function bexpres_get_image_by_size( $params = array() ) {
        $params = array_merge( array(
            'post_id' => null,
            'attach_id' => null,
            'thumb_size' => 'thumbnail',
            'class' => '',
        ), $params );

        if ( ! $params['thumb_size'] ) {
            $params['thumb_size'] = 'thumbnail';
        }

        if ( ! $params['attach_id'] && ! $params['post_id'] ) {
            return false;
        }

        $post_id = $params['post_id'];

        $attach_id = $post_id ? get_post_thumbnail_id( $post_id ) : $params['attach_id'];
        $attach_id = apply_filters( 'pxl_object_id', $attach_id );
        $thumb_size = $params['thumb_size'];
        $thumb_class = ( isset( $params['class'] ) && '' !== $params['class'] ) ? $params['class'] . ' ' : '';

        global $_wp_additional_image_sizes;
        $thumbnail = '';

        $sizes = array(
            'thumbnail',
            'thumb',
            'medium',
            'medium_large',
            'large',
            'full',
        );
        if ( is_string( $thumb_size ) && ( ( ! empty( $_wp_additional_image_sizes[ $thumb_size ] ) && is_array( $_wp_additional_image_sizes[ $thumb_size ] ) ) || in_array( $thumb_size, $sizes, true ) ) ) {
            $attributes = array( 'class' => $thumb_class . 'attachment-' . $thumb_size );
            $thumbnail = wp_get_attachment_image( $attach_id, $thumb_size, false, $attributes );
            $thumbnail_url = wp_get_attachment_image_url($attach_id, $thumb_size, false);
        } elseif ( $attach_id ) {
            if ( is_string( $thumb_size ) ) {
                preg_match_all( '/\d+/', $thumb_size, $thumb_matches );
                if ( isset( $thumb_matches[0] ) ) {
                    $thumb_size = array();
                    $count = count( $thumb_matches[0] );
                    if ( $count > 1 ) {
                        $thumb_size[] = $thumb_matches[0][0]; // width
                        $thumb_size[] = $thumb_matches[0][1]; // height
                    } elseif ( 1 === $count ) {
                        $thumb_size[] = $thumb_matches[0][0]; // width
                        $thumb_size[] = $thumb_matches[0][0]; // height
                    } else {
                        $thumb_size = false;
                    }
                }
            }
            if ( is_array( $thumb_size ) ) {
                // Resize image to custom size
                $p_img = pxl_resize( $attach_id, null, $thumb_size[0], $thumb_size[1], true );
                $alt = trim( wp_strip_all_tags( get_post_meta( $attach_id, '_wp_attachment_image_alt', true ) ) );
                $attachment = get_post( $attach_id );
                if ( ! empty( $attachment ) ) {
                    $title = trim( wp_strip_all_tags( $attachment->post_title ) );

                    if ( empty( $alt ) ) {
                        $alt = trim( wp_strip_all_tags( $attachment->post_excerpt ) ); // If not, Use the Caption
                    }
                    if ( empty( $alt ) ) {
                        $alt = $title;
                    }
                    if ( $p_img ) {

                        $attributes = pxl_stringify_attributes( array(
                            'class' => $thumb_class,
                            'src' => $p_img['url'],
                            'width' => $p_img['width'],
                            'height' => $p_img['height'],
                            'alt' => $alt,
                            'title' => $title,
                        ) );

                        $thumbnail = '<img ' . $attributes . ' />';
                    }
                }
            }
            $thumbnail_url = $p_img['url'];
        }

        $p_img_large = wp_get_attachment_image_src( $attach_id, 'large' );

        return apply_filters( 'pxl_el_getimagesize', array(
            'thumbnail' => $thumbnail,
            'url' => $thumbnail_url,
            'p_img_large' => $p_img_large,
        ), $attach_id, $params );

    }
}

/**
 * Search Form
 */
function bexpres_header_mobile_search_form() {
    $search_mobile = bexpres()->get_theme_opt( 'search_mobile', false );
    if($search_mobile) : ?>
        <div class="pxl-header-mobile-search pxl-hide-xl">
            <?php get_search_form(); ?>
        </div>
    <?php endif; }

/**
 * Year Shortcode [pxl_year]
 */
if (function_exists('pxl_register_shortcode')) {
    function bexpres_year_shortcode() {
        ob_start(); ?>
        <span><?php echo date('Y'); ?></span>
        <?php
        $output = ob_get_clean();
        return $output;
    }
    pxl_register_shortcode('pxl_year', 'bexpres_year_shortcode');
}

/* Highlight Shortcode  */
if(function_exists( 'pxl_register_shortcode' )) {
    function bexpres_text_highlight_shortcode( $atts = array() ) {
        extract(shortcode_atts(array(
           'text' => '',
       ), $atts));

        ob_start();
        if(!empty($text)) : ?>
            <span class="pxl-title--highlight">
                <?php echo esc_attr(sprintf(esc_attr__('%s', 'bexpres'), $text)); ?>
            </span>
        <?php  endif;
        $output = ob_get_clean();

        return $output;
    }
    pxl_register_shortcode('highlight', 'bexpres_text_highlight_shortcode');
}

if(function_exists( 'pxl_register_shortcode' )) {
    function bexpres_edit_text_highlight_shortcode( $atts = array() ) {
        extract(shortcode_atts(array(
           'text' => '',
       ), $atts));

        ob_start();
        if(!empty($text)) : ?>
            <span class="pxl-edit--highlight">
                <?php echo esc_attr(sprintf(esc_attr__('%s', 'bexpres'), $text)); ?>
            </span>
        <?php  endif;
        $output = ob_get_clean();

        return $output;
    }
    pxl_register_shortcode('highlight_edit', 'bexpres_edit_text_highlight_shortcode');
}

if(function_exists( 'pxl_register_shortcode' )) {
    function bexpres_text_sub_highlight_shortcode( $atts = array() ) {
        extract(shortcode_atts(array(
           'text' => '',
       ), $atts));

        ob_start();
        if(!empty($text)) : ?>
            <span class="pxl-sub--highlight">
                <?php echo esc_attr(sprintf(esc_attr__('%s', 'bexpres'), $text)); ?>
            </span>
        <?php  endif;
        $output = ob_get_clean();

        return $output;
    }
    pxl_register_shortcode('sub_highlight', 'bexpres_text_sub_highlight_shortcode');
}

/* Highlight Shortcode  */
if(function_exists( 'pxl_register_shortcode' )) {
    function bexpres_btn_shortcode( $atts = array() ) {
        extract(shortcode_atts(array(
           'text' => '',
           'style' => 'btn-slider1',
           'icon_class' => '',
           'link' => '',
           'text_color' => '',
       ), $atts));

        ob_start();
        if(!empty($text)) : ?>
            <?php if(!empty($link)) : ?><a class="sc-button-wrap" href="<?php echo esc_url($link); ?>"><?php endif; ?>
            <span class='btn <?php echo esc_attr($style); ?> <?php if($style == 'btn-slider1') { echo 'btn-nina'; } ?>' <?php if(!empty($text_color)) { ?>style='color: <?php echo esc_attr($text_color); ?>'<?php } ?>>
                <?php if($style == 'btn-slider1') { ?>
                    <span class='pxl--btn-text' data-text='<?php echo esc_attr(sprintf(esc_attr__('%s', 'bexpres'), $text)); ?>'>
                        <?php $words = explode(' ', $text);
                        foreach ($words as $word) {
                            echo '<span>' . htmlspecialchars($word) . '</span> ';
                        } ?>
                    </span>
                <?php } else {
                    echo esc_attr(sprintf(esc_attr__('%s', 'bexpres'), $text));
                } ?>
                <?php if(!empty($icon_class)) : ?>
                    <i class="<?php echo esc_attr($icon_class); ?>"></i>
                <?php endif; ?>
            </span>
            <?php if(!empty($link)) : ?></a><?php endif; ?>
        <?php  endif;
        $output = ob_get_clean();

        return $output;
    }
    pxl_register_shortcode('pxl_button', 'bexpres_btn_shortcode');
}

/* Gallery Shortcode  */
if(function_exists( 'pxl_register_shortcode' )) {
    function bexpres_gallery_shortcode( $atts = array() ) {
        extract(shortcode_atts(array(
           'link' => '#',
           'images_id' => '',
           'cols' => '2',
           'img_size' => 'full'
       ), $atts));

        ob_start();
        ?>
        <div class="pxl-gallery gallery-<?php echo esc_attr($cols); ?>-columns">
            <?php
            $pxl_images = explode( ',', $images_id );
            foreach ($pxl_images as $key => $img_id) :
                $img = pxl_get_image_by_size( array(
                    'attach_id'  => $img_id,
                    'thumb_size' => $img_size,
                    'class'      => '',
                ));
                $thumbnail = $img['thumbnail'];
                ?>
                <div class="pxl--item">
                    <div class="pxl--item-inner <?php if($key == 1 && !empty($link)) { echo 'video-active'; } ?>">
                        <?php echo pxl_print_html($thumbnail); ?>
                        <?php if($key == 1) : ?>
                            <a href="<?php echo esc_url($link); ?>" class="btn-video"><i class="fa fa-play"></i></a>
                        <?php endif; ?>
                    </div>
                </div>
                <?php
            endforeach;
            ?>
        </div>
        <?php
        $output = ob_get_clean();

        return $output;
    }
    pxl_register_shortcode('pxl_gallery', 'bexpres_gallery_shortcode');
}

/* Addd shortcode Video button */
if(function_exists( 'pxl_register_shortcode' )) {
    function bexpres_video_button_shortcode( $atts = array() ) {
        extract(shortcode_atts(array(
           'link' => '',
           'text' => '',
           'class' => 'style1',
       ), $atts));

        ob_start();
        ?>
        <a href="<?php echo esc_url($link); ?>" class="pxl-button-video1 btn-video pxl-video-popup <?php echo esc_attr($class); ?>">
            <span>
                <i class="caseicon-play1"></i>
            </span>
            <?php if(!empty($text)) : ?>
                <span class="slider-video-title"><?php echo esc_html(sprintf(esc_html__('%s', 'bexpres'), $text)); ?></span>
            <?php endif; ?>
        </a>
        <?php
        $output = ob_get_clean();

        return $output;
    }
    pxl_register_shortcode('pxl_video_button', 'bexpres_video_button_shortcode');
}

/**
 * Custom Widget Categories
 */
add_filter('wp_list_categories', 'bexpres_wg_category_count');
function bexpres_wg_category_count($output) {
    $dir = is_rtl() ? 'pxl-left' : 'pxl-right';
    $output = str_replace("\t", '', $output);
    $output = str_replace(")\n</li>", ')</li>', $output);
    $output = str_replace('</a> (', ' <span class="pxl-count '.$dir.'">(', $output);
    $output = str_replace(")</li>", ")&nbsp;</span></a></li>", $output);
    $output = str_replace(")\n<ul", ")&nbsp;</span></a>\n<ul", $output);
    return $output;
}


/**
 * Custom Widget Archive
 */
add_filter('get_archives_link', 'bexpres_archive_count_span');
function bexpres_archive_count_span($links) {
    $dir = is_rtl() ? 'pxl-left' : 'pxl-right';
    $links = str_replace('</a>&nbsp;(', ' <span class="pxl-count '.$dir.'">(', $links);
    $links = str_replace(')', ')</span></a>', $links);
    return $links;
}


/**
 * Custom Widget Product Categories
 */
add_filter('wp_list_categories', 'bexpres_wc_cat_count_span');
function bexpres_wc_cat_count_span($links) {
    $dir = is_rtl() ? 'pxl-left' : 'pxl-right';
    $links = str_replace('</a> <span class="pxl-count">(', ' <span class="pxl-count '.$dir.'">(', $links);
    $links = str_replace(')</span>', ')</span></a>', $links);
    return $links;
}

/* Search Result  */
function bexpres_custom_post_types_in_search_results( $query ) {
    if ( $query->is_main_query() && $query->is_search() && ! is_admin() ) {
        $query->set( 'post_type', array( 'page', 'post', 'portfolio', 'service', 'product' ) );
    }
}
add_action( 'pre_get_posts', 'bexpres_custom_post_types_in_search_results' );
