<?php

add_action( 'pxl_post_metabox_register', 'bexpres_page_options_register' );
function bexpres_page_options_register( $metabox ) {

	$panels = [
		'post' => [
			'opt_name'            => 'post_option',
			'display_name'        => esc_html__( 'Post Settings', 'bexpres' ),
			'show_options_object' => false,
			'context'  => 'advanced',
			'priority' => 'default',
			'sections'  => [
				'header' => [
					'title'  => esc_html__( 'Post Header', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						bexpres_disable_header_opts([
							'default_value'   => '0'
						]),
						bexpres_header_opts([
							'default'         => true,
							'default_value'   => '-1'
						])
					)
				],
				'post_header_mobile' => [
					'title'  => esc_html__( 'Header Mobile', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						array(
							array(
								'id'       => 'disable_header_mobile_layout',
								'type'     => 'switch',
								'title'    => esc_html__('Disable', 'bexpres'),
								'subtitle' => esc_html__('Disable Mobile Header', 'bexpres'),
								'default'  => '0',
							),
							array(
								'id'       => 'pm_menu',
								'type'     => 'select',
								'title'    => esc_html__( 'Menu', 'bexpres' ),
								'options'  => bexpres_get_nav_menu_slug(),
								'default' => '-1',
							),
						)
					)
				],
				'post_title' => [
					'title'  => esc_html__( 'Post Title', 'bexpres' ),
					'icon'   => 'el el-indent-left',
					'fields' => array_merge(
						bexpres_post_title_opts([
							'default'         => true,
							'default_value'   => '-1'
						])
					)
				],
				'post_settings' => [
					'title'  => esc_html__( 'Post Settings', 'bexpres' ),
					'icon'   => 'el el-refresh',
					'fields' => array_merge(
						bexpres_sidebar_pos_opts(['prefix' => 'post_', 'default' => true, 'default_value' => '-1']),
						array(
							array(
								'id'       => 'post_title_on',
								'title'    => esc_html__('Title', 'bexpres'),
								'subtitle' => esc_html__('Show Title on single post.', 'bexpres'),
								'type'     => 'switch',
								'default'  => true
							),
						),
						array(
							array(
								'id'       => 'post_feature_image_on',
								'title'    => esc_html__('Feature Image', 'bexpres'),
								'subtitle' => esc_html__('Show feature image on single post.', 'bexpres'),
								'type'     => 'switch',
								'default'  => true,
							),
						),
						array(
							array(
								'id'           => 'align_content_post',
								'type'         => 'button_set',
								'title'        => esc_html__( 'Align Content', 'bexpres' ),
								'options'      => array(
									'content-left'  => esc_html__(' Left (Default)', 'bexpres'),
									'content-center' => esc_html__('Center', 'bexpres'),
									'content-right'  => esc_html__('Right', 'bexpres')
								),
								'default'      => 'content-left',
								'force_output' => true
							),
						),
						array(
							array(
								'id'             => 'content_spacing',
								'type'           => 'spacing',
								'output'         => array( '#pxl-wapper #pxl-main' ),
								'right'          => false,
								'left'           => false,
								'mode'           => 'padding',
								'units'          => array( 'px' ),
								'units_extended' => 'false',
								'title'          => esc_html__( 'Spacing Top/Bottom', 'bexpres' ),
								'default'        => array(
									'padding-top'    => '',
									'padding-bottom' => '',
									'units'          => 'px',
								)
							),
						),
					)
				],
			]
		],
		'page' => [
			'opt_name'            => 'pxl_page_options',
			'display_name'        => esc_html__( 'Page Settings', 'bexpres' ),
			'show_options_object' => false,
			'context'  => 'advanced',
			'priority' => 'default',
			'sections'  => [
				'header' => [
					'title'  => esc_html__( 'Header', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						bexpres_disable_header_opts([
							'default_value'   => '0'
						]),
						bexpres_header_opts([
							'default'         => true,
							'default_value'   => '-1'
						]),
						bexpres_header_mobile_opts([
							'default'         => true,
							'default_value'   => '-1'
						]),
						array(
							array(
								'id'       => 'p_menu',
								'type'     => 'select',
								'title'    => esc_html__( 'Menu', 'bexpres' ),
								'options'  => bexpres_get_nav_menu_slug(),
								'default' => '-1',
							),
						),
						array(
							array(
								'id'       => 'sticky_scroll',
								'type'     => 'button_set',
								'title'    => esc_html__('Sticky Scroll', 'bexpres'),
								'options'  => array(
									'pxl-sticky-stt' => esc_html__('Scroll To Top', 'bexpres'),
									'pxl-sticky-stb'  => esc_html__('Scroll To Bottom', 'bexpres'),
								),
								'default'  => 'pxl-sticky-stt',
							),
						),
						bexpres_header_fixed_opts(),
						array(
							array(
								'id'             => 'template_content_spacing',
								'type'           => 'spacing',
								'output'         => array( '#pxl-wapper.header-pos-fixed-left' ),
								'top'          => false,
								'bottom'           => false,
								'mode'           => 'padding',
								'units'          => array( 'px' ),
								'units_extended' => 'false',
								'title'          => esc_html__( 'Spacing Left/Right', 'bexpres' ),
								'default'        => array(
									'padding-left'    => '',
									'padding-right' => '',
									'units'          => 'px',
								)
							),
						),
						array (
							array(
								'id'       => 'template_content_width',
								'type'     => 'dimensions',
								'title'    => esc_html__('Width', 'bexpres'),
								'height'    => false,
								'unit'     => 'px',
								'output'    => array('#pxl-wapper.header-pos-fixed-left header .px-header--default'),
							),
						),
					)
				],
				'header_mobile' => [
					'title'  => esc_html__( 'Header Mobile', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						array(
							array(
								'id'       => 'disable_header_mobile_layout',
								'type'     => 'switch',
								'title'    => esc_html__('Disable', 'bexpres'),
								'subtitle' => esc_html__('Disable Mobile Header', 'bexpres'),
								'default'  => '0',
							),
							array(
								'id'       => 'pm_menu',
								'type'     => 'select',
								'title'    => esc_html__( 'Menu', 'bexpres' ),
								'options'  => bexpres_get_nav_menu_slug(),
								'default' => '-1',
							),
						)
					)
				],
				'page_title' => [
					'title'  => esc_html__( 'Page Title', 'bexpres' ),
					'icon'   => 'el el-indent-left',
					'fields' => array_merge(
						bexpres_page_title_opts([
							'default'         => true,
							'default_value'   => '-1'
						])
					)
				],
				'content' => [
					'title'  => esc_html__( 'Content', 'bexpres' ),
					'icon'   => 'el-icon-pencil',
					'fields' => array_merge(
						bexpres_sidebar_pos_opts(['prefix' => 'page_', 'default' => false, 'default_value' => '0']),
						array(
							array(
								'id'             => 'content_spacing',
								'type'           => 'spacing',
								'output'         => array( '#pxl-wapper #pxl-main' ),
								'right'          => false,
								'left'           => false,
								'mode'           => 'padding',
								'units'          => array( 'px' ),
								'units_extended' => 'false',
								'title'          => esc_html__( 'Spacing Top/Bottom', 'bexpres' ),
								'default'        => array(
									'padding-top'    => '',
									'padding-bottom' => '',
									'units'          => 'px',
								)
							),
							array(
								'id'           => 'loading_page',
								'type'         => 'button_set',
								'title'        => esc_html__( 'Loading', 'bexpres' ),
								'options'      => array(
									'-1'  	   => esc_html__( 'Inherit', 'bexpres' ),
									'bd' 	   => esc_html__( 'Custom', 'bexpres' ),
								),
								'default'      => '-1',
							),
							array(
								'id'           => 'full_page',
								'title'        => esc_html__( 'Full Screen', 'bexpres' ),
								'type'     => 'switch',
								'default'      => false,
							),
							array(
								'id'    => 'loader_style',
								'type'  => 'select',
								'title' => esc_html__('Loader Style', 'bexpres'),
								'subtitle' => esc_html__('ㅤ', 'bexpres'),
								'options' => [
									'style-text'           => esc_html__('Text', 'bexpres'),
									'style-text-blend'     => esc_html__('Text Blend', 'bexpres'),
									'style-triangle'       => esc_html__('Triangle', 'bexpres'),
									'style-home-assistant' => esc_html__('Home Assistant', 'bexpres'),
								],
								'default' => 'style-text',
								'indent' => true,
								'required' => array( 0 => 'loading_page', 1 => 'equals', 2 => 'bd' ),
							),
							array(
								'id'             => 'loading_text',
								'type'           => 'text',
								'title'          => esc_html__('Loading Text', 'bexpres'),
								'default'        => '',
								'desc'           => esc_html__('Enter the text displayed on load.', 'bexpres'),
								'required'       => array( 0 => 'loader_style', 1 => 'equals', 2 => array('style-text', 'style-text-blend') ),
								'force_output'   => true
							),
							array(
								'id'       => 'loader_logo',
								'type'     => 'media',
								'title'    => esc_html__('logo', 'bexpres'),
								'url'      => false,
								'required' => array( 0 => 'loader_style', 1 => 'equals', 2 => array('loader_style', 'style-home-assistant') ),
							),
						)
					)
				],
				'footer' => [
					'title'  => esc_html__( 'Footer', 'bexpres' ),
					'icon'   => 'el el-website',
					'fields' => array_merge(
						array(
							array(
								'id'       => 'disable_footer',
								'title'    => esc_html__('Disable', 'bexpres'),
								'subtitle' => esc_html__('ㅤ', 'bexpres'),
								'type'     => 'switch',
								'default'  => '0',
							),
						),
						bexpres_footer_opts([
							'default'         => true,
							'default_value'   => '-1'
						]),
						array(
							array(
								'id'       => 'p_footer_fixed',
								'type'     => 'button_set',
								'title'    => esc_html__('Footer Fixed', 'bexpres'),
								'options'  => array(
									'inherit' => esc_html__('Inherit', 'bexpres'),
									'on' => esc_html__('On', 'bexpres'),
									'off' => esc_html__('Off', 'bexpres'),
								),
								'default'  => 'inherit',
							),
						)
					)
				],
				'background' => [
					'title'  => esc_html__( 'Background', 'bexpres' ),
					'icon'   => 'el el-photo',
					'fields' => array_merge(
						array(
							array(
								'id'       => 'smooth_scroll',
								'type'     => 'button_set',
								'title'    => esc_html__('Smooth Scroll', 'bexpres'),
								'options'  => array(
									'on' => esc_html__('On', 'bexpres'),
									'off' => esc_html__('Off', 'bexpres'),
								),
								'default'  => 'on',
							),
							array(
								'id'       => 'background_page',
								'title'    => esc_html__('Enable', 'bexpres'),
								'subtitle' => esc_html__('Enable background for page.', 'bexpres'),
								'type'     => 'switch',
								'default'  => '0',
							),
							array(
								'id'       => 'page_bg_light',
								'type'     => 'background',
								'output'   => array( '#pxl-wapper' ),  
								'title'    => esc_html__( 'Background Light', 'bexpres' ),
								'default'  => array(
									'background-image' => '',
								),
								'required' => array( 0 => 'background_page', 1 => 'equals', 2 => '1' ),
								'force_output'   => true
							),
							array(
								'id'       => 'page_bg_dark',
								'type'     => 'background',
								'output'   => array( '.dark-mode #pxl-wapper' ),
								'title'    => esc_html__( 'Background Dark', 'bexpres' ),
								'default'  => array(
									'background-image' => '',
								),
								'required' => array( 0 => 'background_page', 1 => 'equals', 2 => '1' ),
								'force_output'   => true
							),
						),
					)
				],
				'colors' => [
					'title'  => esc_html__( 'Colors', 'bexpres' ),
					'icon'   => 'el el-website',
					'fields' => array_merge(
						array(
							array(
								'id'          => 'primary_color',
								'type'        => 'color',
								'title'       => esc_html__('Primary Color', 'bexpres'),
								'transparent' => false,
								'default'     => ''
							),
							array(
								'id'          => 'secondary_color',
								'type'        => 'color',
								'title'       => esc_html__('Secondary Color', 'bexpres'),
								'transparent' => false,
								'default'     => ''
							),
							array(
								'id'          => 'gradient_color',
								'type'        => 'color_gradient',
								'title'       => esc_html__('Gradient Color', 'bexpres'),
								'transparent' => false,
								'default'  => array(
									'from' => '',
									'to'   => '', 
								),
							),
						)
					)
				]
			]
		],
		'portfolio' => [
			'opt_name'            => 'pxl_portfolio_options',
			'display_name'        => esc_html__( 'Portfolio Options', 'bexpres' ),
			'show_options_object' => false,
			'context'  => 'advanced',
			'priority' => 'default',
			'sections'  => [
				'portfolio_header' => [
					'title'  => esc_html__( 'General', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						bexpres_disable_header_opts([
							'default_value'   => '0'
						]),
						bexpres_header_opts([
							'default'         => true,
							'default_value'   => '-1'
						]),
						array(
							array(
								'id' 	   => 'portfolio_external_link',
								'type' 	   => 'text',
								'title'	   => esc_html__('External Link', 'bexpres'),
								'validate' => 'url',
								'default'  => '',
							),
						)
					)
				],
				'header_mobile' => [
					'title'  => esc_html__( 'Header Mobile', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						array(
							array(
								'id'       => 'disable_header_mobile_layout',
								'type'     => 'switch',
								'title'    => esc_html__('Disable', 'bexpres'),
								'subtitle' => esc_html__('Disable Mobile Header', 'bexpres'),
								'default'  => '0',
							),
							array(
								'id'       => 'pm_menu',
								'type'     => 'select',
								'title'    => esc_html__( 'Menu', 'bexpres' ),
								'options'  => bexpres_get_nav_menu_slug(),
								'default' => '-1',
							),
						)
					)
				],
				'portfolio_content' => [
					'title'  => esc_html__( 'Content', 'bexpres' ),
					'icon'   => 'el-icon-pencil',
					'fields' => array_merge(
						bexpres_sidebar_pos_opts(['prefix' => 'portfolio_', 'default' => false, 'default_value' => '0']),
						array(
							array(
								'id'             => 'content_spacing',
								'type'           => 'spacing',
								'output'         => array( '#pxl-wapper #pxl-main' ),
								'right'          => false,
								'left'           => false,
								'mode'           => 'padding',
								'units'          => array( 'px' ),
								'units_extended' => 'false',
								'title'          => esc_html__( 'Spacing Top/Bottom', 'bexpres' ),
								'default'        => array(
									'padding-top'    => '',
									'padding-bottom' => '',
									'units'          => 'px',
								)
							),
							array(
								'id'      => 'nav_red_pos',
								'title'   => esc_html__('Navigation & Related Projects Position', 'bexpres'),
								'type'    => 'button_set',
								'options' => array(
									'left'  => esc_html__('Left','bexpres'),
									'center' => esc_html__('Center','bexpres'),
									'right' => esc_html__('Right','bexpres'),
								),
								'default' => 'center',
							),
							array(
								'id'           => 'portfolio_nav_link_cus',
								'type'         => 'button_set',
								'title'        => esc_html__( 'Navigation Button Link', 'bexpres' ),
								'options'      => array(
									'-1'  	   => esc_html__( 'Inherit', 'bexpres' ),
									'custom' 	   => esc_html__( 'Custom', 'bexpres' ),
								),
								'default'      => '-1',
							),
							array(
								'id'       => 'portfolio_nav_link_page',
								'type'     => 'text',
								'title'    => esc_html__('Navigation Button Link', 'bexpres'),
								'subtitle' => esc_html__('Enter navigation middle button link.', 'bexpres'),
								'default'  => '#',
								'required' => array( 0 => 'portfolio_nav_link_cus', 1 => 'equals', 2 => 'custom' ),
							),
						)
					)
				],
				'portfolio_footer' => [
					'title'  => esc_html__( 'Footer', 'bexpres' ),
					'icon'   => 'el el-website',
					'fields' => array_merge(
						bexpres_footer_opts([
							'default'         => true,
							'default_value'   => '-1'
						])
					)
				],
				'portfolio_page_title' => [
					'title'  => esc_html__( 'Page Title', 'bexpres' ),
					'icon'   => 'el el-indent-left',
					'fields' => array_merge(
						bexpres_page_title_opts([
							'default'         => true,
							'default_value'   => '-1'
						])
					)
				],
			]
		],
		'service' => [
			'opt_name'            => 'pxl_service_options',
			'display_name'        => esc_html__( 'Service Settings', 'bexpres' ),
			'show_options_object' => false,
			'context'  => 'advanced',
			'priority' => 'default',
			'sections'  => [
				'header' => [
					'title'  => esc_html__( 'General', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						array(
							array(
								'id'=> 'service_external_link',
								'type' => 'text',
								'title' => esc_html__('External Link', 'bexpres'),
								'validate' => 'url',
								'default' => '',
							),
							array(
								'id'       => 'service_icon_type',
								'type'     => 'button_set',
								'title'    => esc_html__('Icon Type', 'bexpres'),
								'options'  => array(
									'icon'  => esc_html__('Icon', 'bexpres'),
									'image'  => esc_html__('Image', 'bexpres'),
								),
								'default'  => 'icon'
							),
							array(
								'id'       => 'service_icon_font',
								'type'     => 'pxl_iconpicker',
								'title'    => esc_html__('Icon', 'bexpres'),
								'required' => array( 0 => 'service_icon_type', 1 => 'equals', 2 => 'icon' ),
								'force_output' => true
							),
							array(
								'id'       => 'service_img_light',
								'type'     => 'media',
								'title'    => esc_html__('Icon Image Light', 'bexpres'),
								'default' => '',
								'required' => array( 0 => 'service_icon_type', 1 => 'equals', 2 => 'image' ),
								'force_output' => true
							),
							array(
								'id'       => 'service_img_dark',
								'type'     => 'media',
								'title'    => esc_html__('Icon Image Dark', 'bexpres'),
								'default' => '',
								'required' => array( 0 => 'service_icon_type', 1 => 'equals', 2 => 'image' ),
								'force_output' => true
							),
							array(
								'id'             => 'content_spacing',
								'type'           => 'spacing',
								'output'         => array( '#pxl-wapper #pxl-main' ),
								'right'          => false,
								'left'           => false,
								'mode'           => 'padding',
								'units'          => array( 'px' ),
								'units_extended' => 'false',
								'title'          => esc_html__( 'Content Spacing Top/Bottom', 'bexpres' ),
								'default'        => array(
									'padding-top'    => '',
									'padding-bottom' => '',
									'units'          => 'px',
								)
							),
						)
					)
				],
				
				'header_service' => [
					'title'  => esc_html__( 'Header', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						bexpres_disable_header_opts([
							'default_value'   => '0'
						]),
						bexpres_header_opts([
							'default'         => true,
							'default_value'   => '-1'
						]),
						array(
							array(
								'id'       => 'p_menu',
								'type'     => 'select',
								'title'    => esc_html__( 'Menu', 'bexpres' ),
								'options'  => bexpres_get_nav_menu_slug(),
								'default' => '-1',
							),
						)
					)

				],
				'header_mobile' => [
					'title'  => esc_html__( 'Header Mobile', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						array(
							array(
								'id'       => 'disable_header_mobile_layout',
								'type'     => 'switch',
								'title'    => esc_html__('Disable', 'bexpres'),
								'subtitle' => esc_html__('Disable Mobile Header', 'bexpres'),
								'default'  => '0',
							),
							array(
								'id'       => 'pm_menu',
								'type'     => 'select',
								'title'    => esc_html__( 'Menu', 'bexpres' ),
								'options'  => bexpres_get_nav_menu_slug(),
								'default' => '-1',
							),
						)
					)
				],
				
				'footer' => [
					'title'  => esc_html__( 'Footer', 'bexpres' ),
					'icon'   => 'el el-website',
					'fields' => array_merge(
						array(
							array(
								'id'       => 'disable_footer',
								'title'    => esc_html__('Disable', 'bexpres'),
								'subtitle' => esc_html__('ㅤ', 'bexpres'),
								'type'     => 'switch',
								'default'  => '0',
							),
						),
						bexpres_footer_opts([
							'default'         => true,
							'default_value'   => '-1'
						])
					)
				],
				'page_title' => [
					'title'  => esc_html__( 'Page Title', 'bexpres' ),
					'icon'   => 'el el-indent-left',
					'fields' => array_merge(
						bexpres_page_title_opts([
							'default'         => true,
							'default_value'   => '-1'
						])
					)
				],
			
			]
		],
		'product' => [
			'opt_name'            => 'pxl_product_options',
			'display_name'        => esc_html__( 'Product Settings', 'bexpres' ),
			'show_options_object' => false,
			'context'  => 'advanced',
			'priority' => 'default',
			'sections'  => [
				'header_product' => [
					'title'  => esc_html__( 'Header', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						bexpres_disable_header_opts([
							'default_value'   => '0'
						]),
						bexpres_header_opts([
							'default'         => true,
							'default_value'   => '-1'
						]),
						array(
							array(
								'id'       => 'p_menu',
								'type'     => 'select',
								'title'    => esc_html__( 'Menu', 'bexpres' ),
								'options'  => bexpres_get_nav_menu_slug(),
								'default' => '-1',
							),
						)
					)

				],
				'header_mobile' => [
					'title'  => esc_html__( 'Header Mobile', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array_merge(
						array(
							array(
								'id'       => 'disable_header_mobile_layout',
								'type'     => 'switch',
								'title'    => esc_html__('Disable', 'bexpres'),
								'subtitle' => esc_html__('Disable Mobile Header', 'bexpres'),
								'default'  => '0',
							),
							array(
								'id'       => 'pm_menu',
								'type'     => 'select',
								'title'    => esc_html__( 'Menu', 'bexpres' ),
								'options'  => bexpres_get_nav_menu_slug(),
								'default' => '-1',
							),
						)
					)
				],
				'page_title' => [
					'title'  => esc_html__( 'Page Title', 'bexpres' ),
					'icon'   => 'el el-indent-left',
					'fields' => array_merge(
						bexpres_page_title_shop_opts([
							'default'         => true,
							'default_value'   => 'df'
						])
					)
				],
			]
		],
		'pxl-template' => [
			'opt_name'            => 'pxl_hidden_template_options',
			'display_name'        => esc_html__( 'Template Settings', 'bexpres' ),
			'show_options_object' => false,
			'context'  => 'advanced',
			'priority' => 'default',
			'sections'  => [
				'header' => [
					'title'  => esc_html__( 'General', 'bexpres' ),
					'icon'   => 'el-icon-website',
					'fields' => array(
						array(
							'id'    => 'template_type',
							'type'  => 'select',
							'title' => esc_html__('Type', 'bexpres'),
							'options' => [
								'df'       	   => esc_html__('Select Type', 'bexpres'),
								'header'       => esc_html__('Header', 'bexpres'),
								'footer'       => esc_html__('Footer', 'bexpres'),
								'mega-menu'    => esc_html__('Mega Menu', 'bexpres'),
								'page-title'   => esc_html__('Page Title', 'bexpres'),
								'tab' => esc_html__('Tab', 'bexpres'),
								'hidden-panel' => esc_html__('Hidden Panel', 'bexpres'),
								'widget' => esc_html__('Widget Sidebar', 'bexpres'),
								'shop' => esc_html__('Shop', 'bexpres'),
							],
							'default' => 'df',
						),
						array(
							'id'    => 'header_type',
							'type'  => 'button_set',
							'title' => esc_html__('Header Type', 'bexpres'),
							'options' => [
								'px-header--default'       	   => esc_html__('Default', 'bexpres'),
								'px-header--transparent'       => esc_html__('Transparent', 'bexpres'),
							],
							'default' => 'px-header--default',
							'indent' => true,
							'required' => array( 0 => 'template_type', 1 => 'equals', 2 => 'header' ),
						),
						array(
							'id'       => 'template_position',
							'type'     => 'select',
							'title'    => esc_html__('Display Position', 'bexpres'),
							'options'  => [
								'left'   => esc_html__('Left Position', 'bexpres'),
								'top'    => esc_html__('Top Position', 'bexpres'),
								'center' => esc_html__('Center Position (popup)', 'bexpres'),
								'right'  => esc_html__('Right Position', 'bexpres'),
								'full'   => esc_html__('Full Screen', 'bexpres'),
							],
							'default'  => 'left',
							'required' => [ 'template_type', '=', 'hidden-panel']
						),
						array(
							'id'       => 'header_position',
							'type'     => 'select',
							'title'    => esc_html__('Header Position', 'bexpres'),
							'options'  => [
								'df'   => esc_html__('Default', 'bexpres'),
								'fixed-left'    => esc_html__('Fixed Left', 'bexpres'),
								'fixed-right' => esc_html__('Fixed Right', 'bexpres')
							],
							'default'  => 'df',
							'required' => [ 'template_type', '=', 'header']
						),
					),

				],
			]
		],
	];

	$metabox->add_meta_data( $panels );
}
